<?php
// Konfigurasi
$cacheDuration = 3600; // Durasi cache 1 jam
$cacheDir = 'cache/anime'; // Direktori cache

// Ambil endpoint dari URL
$request_uri = $_SERVER['REQUEST_URI'];
$page = explode('/', $request_uri);
$anime_info = isset($page[2]) ? rtrim($page[2], '/') : '';

// URL API
$apiUrl = "$api/api/anime/anime/$anime_info";

// Nama file cache berdasarkan hash endpoint
$cacheFile = $cacheDir . '/' . md5($anime_info) . '.json';

// Fungsi untuk mengambil data dari API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Fungsi untuk mendapatkan data dari cache atau API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();

  // Periksa apakah file cache ada dan masih berlaku
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Ambil data dari API dan simpan ke cache
  $data = fetchData($apiUrl);
  if (isset($data['status']) && $data['status'] === true) {
    file_put_contents($cacheFile, json_encode($data));
  }

  return $data;
}

// Ambil data dengan caching
$data = getData($cacheFile, $apiUrl, $cacheDuration);
$animeData = $data['data'] ?? [];
$eplister = $animeData['eplister'] ?? [];
$recommendations = $animeData['recommendations'] ?? [];
?>
<html lang="en" class="dark text-foreground bg-background">
<head>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1" />
  <meta name="theme-color" content="#05010d" />
  <title><?php
    echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> | <?=$site_TITLE ?> - Nonton Anime Subtitle Indonesia</title>
  <meta name="description" content="<?= substr($animeData['sinopsis'], 0, 150) ?> - Nonton <?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> di <?=$site_TITLE ?>" />
  <meta name="application-name" content="<?=$site_TITLE ?>" />
  <link rel="manifest" href="/manifest.json" crossorigin="use-credentials" />
  <link rel="canonical" href="<?=$siteURL ?>/anime/<?=$anime_info ?>" />
  <meta name="keywords" content="<?=$site_TITLE ?>, anime, nonton <?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> online, <?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> streaming, download <?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> subtitle Indonesia, <?=$site_TITLE ?> anime" />
  <meta name="format-detection" content="telephone=no" />
  <meta name="apple-mobile-web-app-capable" content="yes" />
  <meta name="apple-mobile-web-app-title" content="<?=$site_TITLE ?> - Nonton anime online" />
  <meta name="apple-mobile-web-app-status-bar-style" content="default" />
  <meta property="og:url" content="<?=$siteURL ?>/anime/<?=$anime_info ?>" />
  <meta property="og:title" content="<?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> - Nonton Subtitle Indonesia" />
  <meta property="og:description" content="<?= substr($animeData['sinopsis'], 0, 150) ?> - Nonton anime di <?=$site_TITLE ?>" />
  <meta property="og:image" content="<?= $animeData['images'] ?>" />
  <meta name="twitter:card" content="summary" />
  <meta name="twitter:title" content="<?php echo isset($animeData['title']) ? str_replace('Sub Indo', '', $animeData['title']) : 'N/A'; ?> - Nonton Subtitle Indonesia" />
  <meta name="twitter:description" content="<?= substr($animeData['sinopsis'], 0, 150) ?> - Nonton anime di <?=$site_TITLE ?>" />
  <meta name="twitter:image" content="<?= $animeData['images'] ?>" />
  <link rel="shortcut icon" href="/favicon-16x16.png" />
  <link rel="apple-touch-icon" href="/apple-touch-icon.png" />
  <meta name="next-size-adjust" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/dbf317c5a42383e0.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/334dd403868c5153.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/1ccc80749f9874d3.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/a5eef6a901953dd4.css" />
  <script src="https://cdn.tailwindcss.com"></script>
</head>
<body>
  <div>
    <?php include('inc/navbar.php'); ?>
    <div class="w-screen max-w-full overflow-hidden lg:pl-9">
      <div class="h-[500px]">
        <div class="AnimeDetailsTop_detailsbanner__O2s9w">
          <div
            class="AnimeDetailsTop_detailsbgimage__QHMrr"
            style="background-image: url(<?= $animeData['images'] ?>); background-position: center; background-size: cover; height: 100%;"
            ></div>
          <div class="AnimeDetailsTop_gradientOverlay__g3uf8"></div>
          <div class="lg:block hidden absolute h-[101%] w-full bg-gradient-to-r from-[#05010e] left-4 from-0% to-transparent to-40%"></div>
          <div class="absolute h-[101%] w-full bg-gradient-to-b from-black/70 from-0% to-transparent to-30%"></div>
          <div class="AnimeDetailsTop_detailstrailer__souhn text-sm hidden md:flex items-center gap-2 modalYtta">
            <button class="px-3 py-2 bg-white text-black rounded-xl">Trailer</button>
          </div>
          <div class="AnimeDetailsTop_detailsinfo__CBeLz">
            <div class="AnimeDetailsTop_detailsimgcon__6vDUf">
              <img
              alt="Image"
              loading="lazy"
              width="200"
              height="200"
              decoding="async"
              data-nimg="1"
              class="AnimeDetailsTop_detailsimage__JoMvk"
              style="color: transparent;"
              src="<?= $animeData['images'] ?>"
              />
            </div>
            <div class="AnimeDetailsTop_detailstitle___n4ki">
              <h1 class="AnimeDetailsTop_title__THumD text-[1.7rem] lg:text-[1.9rem] font-semibold"><?= $animeData['title'] ?></h1>
              <h4 class="AnimeDetailsTop_alttitle__6qsft !font-medium"><?= $animeData['title'] ?></h4>
              <p class="AnimeDetailsTop_scores__aDYg4">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-[17px] h-[17px] mr-[2px]">
                  <path
                    stroke-linecap="round"
                    stroke-linejoin="round"
                    d="M11.48 3.499a.562.562 0 011.04 0l2.125 5.111a.563.563 0 00.475.345l5.518.442c.499.04.701.663.321.988l-4.204 3.602a.563.563 0 00-.182.557l1.285 5.385a.562.562 0 01-.84.61l-4.725-2.885a.563.563 0 00-.586 0L6.982 20.54a.562.562 0 01-.84-.61l1.285-5.386a.562.562 0 00-.182-.557l-4.204-3.602a.563.563 0 01.321-.988l5.518-.442a.563.563 0 00.475-.345L11.48 3.5z"
                    ></path>
                </svg>
                <?= $animeData['rating'] !== "" ? $animeData['rating'] : "N/A" ?>
                <!-- -->| <span class="AnimeDetailsTop_activestatus__4_CXd font-medium"><?= $animeData['info']['Status'] !== "" ? $animeData['info']['Status'] : "N/A" ?>
                </p>
              </span>
            </p>
            <div class="flex items-center">
              <button class="AnimeDetailsTop_detailsaddlist__mXF4V hover:opacity-80 transition-all">Add to List</button>
            </div>
          </div>
        </div>
        <div class="fixed inset-0 flex justify-center items-center z-50 h-screen w-screen invisible">
          <div class="bg-[#17171c] shadow-md shadow-black/70 rounded-xl transition-all py-3 scale-75 opacity-0">
            <button class="absolute top-2 right-2 p-1 rounded-lg text-gray-400 bg-content1 hover:text-white">
              <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 15 15">
                <path
                  fill="currentColor"
                  d="M3.64 2.27L7.5 6.13l3.84-3.84A.92.92 0 0 1 12 2a1 1 0 0 1 1 1a.9.9 0 0 1-.27.66L8.84 7.5l3.89 3.89A.9.9 0 0 1 13 12a1 1 0 0 1-1 1a.92.92 0 0 1-.69-.27L7.5 8.87l-3.85 3.85A.92.92 0 0 1 3 13a1 1 0 0 1-1-1a.9.9 0 0 1 .27-.66L6.16 7.5L2.27 3.61A.9.9 0 0 1 2 3a1 1 0 0 1 1-1c.24.003.47.1.64.27"
                  ></path>
              </svg>
            </button>
            <div class="px-5 pt-4 pb-2">
              <div class="max-w-[90%] hidden md:flex">
                <h3 class="text-2xl font-semibold text-textp line-clamp-1"><?= $animeData['title'] ?></h3>
              </div>
              <div class="w-[650px] h-[350px] my-2"></div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <div class="AnimeDetailsBottom_detailstabs__hVi_H">
      <div class="AnimeDetailsBottom_tabHeader__HFVgw">
        <div class="AnimeDetailsBottom_tabItem__00i_M AnimeDetailsBottom_selected__yKotU">
          Overview
          <div class="AnimeDetailsBottom_indicator__03rn1"></div>
        </div>
      </div>
      <div>
        <div class="AnimeDetailsBottom_detailscard__cDaTT">
          <div class="AnimeDetailsBottom_card1__CS2TA">
            <h3 class="AnimeDetailsBottom_detailsheading__GaG5c">Detail</h3>
            <div>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r font-semibold !text-[15px]">Status</span>
                <span class="AnimeDetailsBottom_con__uOKud !text-white cursor-pointer font-semibold">
                  <?= $animeData['info']['Status'] ?>
                </span>
              </div>
              <?php if (!empty($animeData['info']['Jenis'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Type</span>
                <span class="AnimeDetailsBottom_con__uOKud"><?= htmlspecialchars($animeData['info']['Jenis']) ?></span>
              </div>
              <?php endif; ?>
              <?php if (!empty($animeData['info']['Durasi'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Durasi</span>
                <span class="AnimeDetailsBottom_con__uOKud"><?= htmlspecialchars($animeData['info']['Durasi']) ?></span>
              </div>
              <?php endif; ?>
              <?php if (!empty($animeData['info']['Rilis di'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Rilis</span>
                <span class="AnimeDetailsBottom_con__uOKud">
                  <?= htmlspecialchars($animeData['info']['Rilis di']) ?>
                </span>
              </div>
              <?php endif; ?>
              <?php if (!empty($animeData['info']['Musim'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Season</span>
                <span class="AnimeDetailsBottom_con__uOKud">
                  <a href="<?= htmlspecialchars($siteURL . $animeData['info']['Musim_link']) ?>">
                    <?= htmlspecialchars($animeData['info']['Musim']) ?>
                  </a>
                </span>
              </div>
              <?php endif; ?>
              <?php if (!empty($animeData['info']['Studio'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Studios</span>
                <span class="AnimeDetailsBottom_con__uOKud">
                  <a href="<?= htmlspecialchars($siteURL . $animeData['info']['Studio_link']) ?>">
                    <?= htmlspecialchars($animeData['info']['Studio']) ?>
                  </a>
                </span>
              </div>
              <?php endif; ?>
              <?php if (!empty($animeData['genre'])): ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Genres</span>
                <?php
                $maxGenres = 4;
                $count = 0;
                foreach ($animeData['genre'] as $genre):
                if ($count >= $maxGenres) break;
                ?>
                <span class="AnimeDetailsBottom_con__uOKud">
                  <a href="<?= htmlspecialchars($genre['link']) ?>"><?= htmlspecialchars($genre['name']) ?>, </a>
                </span>
                <?php
                $count++;
                endforeach;
                ?>
              </div>
              <?php endif; ?>
              <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                <span class="AnimeDetailsBottom_sideheading__aPw8r">Kredit</span> <span class="AnimeDetailsBottom_con__uOKud"><a href="https://tv.animisme.net/anime/<?=$anime_info ?>">animisme.net</a></span>
              </div>
            </div>
          </div>
          <div class="AnimeDetailsBottom_card2__m40_q">
            <div class="flex justify-between items-center mb-1.5">
              <h3 class="AnimeDetailsBottom_detailsheading__GaG5c font-semibold m-0">Description</h3>
              <div class="flex gap-3 items-center md:hidden modalYtta">

                <button class="text-sm bg-white text-black px-2 rounded-lg h-min py-1 opacity-95 font-medium">Trailer</button>
              </div>
            </div>
            <div class="AnimeDetailsBottom_descriptioncontent__v_ijv tracking-normal">
              <p>
                <?= $animeData['sinopsis'] ?>
              </p>
            </div>
            <div class="AnimeDetailsBottom_descriptioncontentmobile__DLX6k">
              <p>
                <?= $animeData['sinopsis'] ?>
              </p>
            </div>
          </div>
          <div class="fixed inset-0 flex justify-center items-center z-50 h-screen w-screen invisible">
            <div class="bg-[#17171c] shadow-md shadow-black/70 rounded-xl transition-all py-3 scale-75 opacity-0">
              <button class="absolute top-2 right-2 p-1 rounded-lg text-gray-400 bg-content1 hover:text-white">
                <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 15 15">
                  <path
                    fill="currentColor"
                    d="M3.64 2.27L7.5 6.13l3.84-3.84A.92.92 0 0 1 12 2a1 1 0 0 1 1 1a.9.9 0 0 1-.27.66L8.84 7.5l3.89 3.89A.9.9 0 0 1 13 12a1 1 0 0 1-1 1a.92.92 0 0 1-.69-.27L7.5 8.87l-3.85 3.85A.92.92 0 0 1 3 13a1 1 0 0 1-1-1a.9.9 0 0 1 .27-.66L6.16 7.5L2.27 3.61A.9.9 0 0 1 2 3a1 1 0 0 1 1-1c.24.003.47.1.64.27"
                    ></path>
                </svg>
              </button>
            </div>
          </div>
        </div>
      </div>
    </div>
    <div id="yttaOverlay" class="backdrop-blur-sm fixed inset-0 z-50 hidden w-full h-full bg-black bg-opacity-50 flex items-center justify-center">
      <div class="relative w-11/12 max-w-xl bg-transparent">
        <iframe id="youtubeIframe" src="" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen class="w-full aspect-video" frameborder="0"></iframe>
      </div>
    </div>
    <div class="Episodesection_episodesection__Pz__g">
      <div class="Episodesection_eptopsection__S00Yy">
        <div class="Episodesection_epleft__ReCcn">
          <div class="flex items-center gap-2">
            <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
            <h1 class="text-[19px] sm:text-[22px] font-medium md:font-semibold">Episode</h1>
          </div>
          <button class="Episodesection_refresh__CiIMr">
            <svg xmlns="http://www.w3.org/2000/svg" class="ml-1 w-[22px] h-[22px] md:w-[24px] md:h-[23px]" viewBox="0 0 24 24">
              <path fill="currentColor" d="M12 17q.425 0 .713-.288T13 16t-.288-.712T12 15t-.712.288T11 16t.288.713T12 17m-1-4h2V7h-2zm-2.75 8L3 15.75v-7.5L8.25 3h7.5L21 8.25v7.5L15.75 21zm.85-2h5.8l4.1-4.1V9.1L14.9 5H9.1L5 9.1v5.8zm2.9-7"></path>
            </svg>
          </button>
        </div>
        <div class="Episodesection_epright__6UDxQ">
          <div class="Episodesection_selects__qJVPp">
            <div class="flex w-[75px] flex-col gap-2 mr-2">
              <div
                data-slot="base"
                data-filled="true"
                data-has-value="true"
                class="group flex flex-col w-full transition-background motion-reduce:transition-none !duration-150 group relative justify-end data-[has-label=true]:mt-[calc(theme(fontSize.small)_+_10px)] !m-0 !p-0"
                >
              </div>
            </div>
          </div>
        </div>
      </div>
      <div>
        <div class="Epimglist_epimgcondiv__UVpLl">
          <?php if (!empty($animeData['eplister'])): ?>
          <?php foreach ($animeData['eplister'] as $episode): ?>
          <a
            class="flex flex-row items-center transition-all duration-300 ease-out hover:scale-[0.98] hover:bg-[#27272c] rounded-lg xl:rounded-2xl my-[6px] bg-[#18181b]"
            href="/episode<?= $episode['link'] ?>"
            >
            <div class="Epimglist_epcondiv__f_l4B rounded-lg xl:rounded-2xl">
              <img
              alt="<?= $episode['title'] ?>"
              loading="lazy"
              width="200"
              height="200"
              decoding="async"
              data-nimg="1"
              class="Epimglist_epimgcon__Uj_1I rounded-lg xl:rounded-2xl"
              src="<?= $animeData['images'] ?>"
              style="color: transparent;"
              />
              <span class="Epimglist_epimgnumber__D_H8G font-semibold">EP <?= $episode['epnum'] ?></span>
              <div class="absolute bottom-0 left-0 w-full rounded-lg z-10">
                <hr class="border-red-600 !border-[.10rem] rounded-lg xl:rounded-2xl" style="width: 0%;" />
              </div>
            </div>
            <div class="Epimglist_epimgright__CBLYG">
              <div class="Epimglist_epimgtitle__iuJmy font-medium">
                <?= $episode['title'] ?>
              </div>
              <div class="Epimglist_epimgdescription__jMNPY font-normal tracking-wide">
                <?= $episode['date'] ?>
              </div>
              <div class="flex flex-row gap-6"></div>
            </div>
          </a>
          <?php endforeach; ?>
          <?php else : ?>
          <div class="text-center text-white bg-[#27272c] p-4 rounded-lg xl:rounded-2xl">
            Not Available
          </div>
          <?php endif; ?>
        </div>

      </div>
    </div>

    <div class="recommendationglobal">
      <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
        <div class="flex items-center gap-2 px-3 xl:px-0">
          <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
          <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Rekomen</h1>
        </div>
        <div class="relative">
          <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full">
            <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
              <path d="m15 18-6-6 6-6"></path>
            </svg>
          </span>
          <span class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
            <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
              <path d="m9 18 6-6-6-6"></path>
            </svg>
          </span>
          <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0" id="Recommendations" style="cursor: auto;">
            <?php if (!empty($animeData['recommendations'])): ?>
            <?php foreach ($animeData['recommendations'] as $rekomen): ?>
            <a href="<?= htmlspecialchars($rekomen['link']) ?>" style="cursor: pointer;">
              <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                  <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                    <img
                    alt="<?= htmlspecialchars($rekomen['title']) ?>"
                    loading="eager"
                    width="155"
                    height="230"
                    decoding="async"
                    data-nimg="1"
                    class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105"
                    style="color: transparent;"
                    src="<?= htmlspecialchars($rekomen['img']) ?>"
                    />
                  </div>
                  <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                    <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                      <?php if (!empty($rekomen['type'])): ?>
                      <span class="uppercase"><?= htmlspecialchars($rekomen['type']) ?></span>
                      <span class="text-[10px]">•</span>
                      <?php endif; ?>
                      <?php if (!empty($rekomen['epx'])): ?>
                      <span class="font-semibold text-white random-color"><?= htmlspecialchars($rekomen['epx']) ?></span>
                      <?php endif; ?>
                    </div>
                  </div>
                </div>
                <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2">
                  <span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full hidden xl:hidden"></span><?= htmlspecialchars($rekomen['title']) ?>
                </span>
              </div>
            </a>
            <?php endforeach; ?>
            <?php else : ?>
            <div class="text-center text-white bg-[#27272c] p-4 rounded-lg xl:rounded-2xl">
              Not Available
            </div>
            <?php endif; ?>
          </div>
        </div>
      </div>
    </div>

  </div>
  <!-- footer -->
  <?php include('inc/footer.php'); ?>
  <script>
    document.addEventListener('DOMContentLoaded', () => {
      const modals = document.querySelectorAll('.modalYtta');
      const yttaOverlay = document.getElementById('yttaOverlay');
      const youtubeIframe = document.getElementById('youtubeIframe');
      const videoId = '<?php echo $animeData['trailer']; ?>';
      youtubeIframe.src = `https://www.youtube.com/embed/${videoId}`;
      const openModal = () => {
        yttaOverlay.classList.remove('hidden');
        youtubeIframe.src = `https://www.youtube.com/embed/${videoId}`;
      };
      const closeModal = () => {
        yttaOverlay.classList.add('hidden');
        youtubeIframe.src = '';
      };
      modals.forEach(modal => {
        modal.addEventListener('click', openModal);
      });
      yttaOverlay.addEventListener('click', (e) => {
        if (e.target === yttaOverlay) {
          closeModal();
        }
      });
    });
  </script>
</div>
</body>
</html>