<?php
$request_uri = $_SERVER['REQUEST_URI'];
$page = explode('/', $request_uri);
$komik_ch = isset($page[2]) ? rtrim($page[2], '/') : '';

// File cache
$cacheDuration = 3600; // 1 jam
$cacheFile = 'cache/chapter/' . md5($komik_ch) . '.json'; // Nama file cache berdasarkan hash endpoint

// Fungsi untuk mengambil data dari API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Fungsi untuk mendapatkan data dari cache atau API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();

  // Jika file cache ada dan masih berlaku
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Ambil data dari API dan simpan ke cache
  $data = fetchData($apiUrl);
  if (isset($data['status']) && $data['status'] === true) {
    file_put_contents($cacheFile, json_encode($data));
  }

  return $data;
}

// Tentukan URL API untuk endpoint
$apiUrl = "$api/api/komik/chapter/$komik_ch";

// Ambil data dengan caching
$data = getData($cacheFile, $apiUrl, $cacheDuration);

// Tampilkan halaman HTML
?>
<html lang="en" class="dark text-foreground bg-background" style="">

<head>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="theme-color" content="#05010d">
  <meta charset="utf-8">
  <title><?php echo "Chapter " . (preg_match('/Chapter (\d+)/', $data['data']['title'] ?? 'N/A', $m) ? $m[1] : 'N/A'); ?> - <?= preg_replace('/Komik|Chapter \d+/', '', $data['data']['title'] ?? 'N/A'); ?> | <?=$site_TITLE ?> - Baca Komik Indonesia</title>
  <meta name="description" content="<?=$data['data']['shortDescription'] ? substr($data['data']['shortDescription'], 0, 140) . (strlen($data['data']['shortDescription']) > 140 ? '...' : '') : 'N/A'; ?> | <?=$data['data']['title'] ?? 'N/A'; ?> Hanya di <?=$site_TITLE ?> ">
  <meta name="keywords" content="Baca komik, Manga Indonesia, Komik terbaru, Komik online, Komik populer, <?=$data['data']['title'] ?? 'N/A'; ?> chapter, <?=$site_TITLE ?>, baca manga, baca komik online terbaik, <?=$data['data']['title'] ?? 'N/A'; ?> chapter terbaru, komikindo, mangaku, bacamanga, komikcast, mangakita, komiku, komikstation, mangadop, westmanga, otakudesu, komikid, komikindo.web.id, manganime, mangacanblog, samehadaku, mangatoon, bacamanga.cc, komikidn, mangakita.net, komikstation.com">
  <meta name="application-name" content="<?=$site_TITLE ?>">
  <meta property="og:type" content="article">
  <meta property="og:url" content="<?=$siteURL ?>/chapter/<?=$komik_ch ?>" />
  <meta property="og:title" content="<?=$data['data']['title'] ?? 'N/A'; ?> Chapter | <?=$site_TITLE ?> - Baca Komik Indonesia">
  <meta property="og:description" content="<?=$data['data']['shortDescription'] ? substr($data['data']['shortDescription'], 0, 140) . (strlen($data['data']['shortDescription']) > 140 ? '...' : '') : 'N/A'; ?> | <?=$data['data']['title'] ?? 'N/A'; ?> Hanya di <?=$site_TITLE ?>">
  <meta property="og:image" content="<?=$data['data']['thumbnail'] ?? 'https://yourimageshare.com/ib/JEac99QgEq.webp'; ?>">
  <meta property="og:site_name" content="<?=$site_TITLE ?>">
  <meta name="twitter:card" content="summary_large_image">
  <meta name="twitter:title" content="<?=$data['data']['title'] ?? 'N/A'; ?> Chapter | <?=$site_TITLE ?> - Baca Komik Indonesia">
  <meta name="twitter:description" content="<?=$data['data']['shortDescription'] ? substr($data['data']['shortDescription'], 0, 140) . (strlen($data['data']['shortDescription']) > 140 ? '...' : '') : 'N/A'; ?> | <?=$data['data']['title'] ?? 'N/A'; ?> Hanya di <?=$site_TITLE ?>">
  <meta name="twitter:image" content="<?=$data['data']['thumbnail'] ?? 'https://yourimageshare.com/ib/JEac99QgEq.webp'; ?>">
  <link rel="canonical" href="<?=$siteURL ?>/chapter/<?=$komik_ch ?>" />
  <link rel="shortcut icon" href="/favicon-16x16.png">
  <link rel="apple-touch-icon" href="/apple-touch-icon.png">
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy2.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy3.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy4.css" />
  <script src="https://cdn.tailwindcss.com"></script>
  <meta name="next-size-adjust">
  <link rel="preconnect" href="https://cdn.jsdelivr.net/npm/hls.js@^1.5.0/dist/hls.min.js" crossorigin="true">
  <script src="https://cdn.jsdelivr.net/npm/hls.js@^1.5.0/dist/hls.min.js"></script>
</head>
<body class="__className_7df6af">
  <div>
    <?php
    include('inc/nav.php')
    ?>
    <main class="relative px-4 sm:px-6 lg:px-8 max-w-6xl mx-auto min-h-[79vh] bg-black mt-24">
      <div class="mt-6 flex flex-col">
        <h1 class="title text-xl text-center font-semibold text-white"><?=$data['data']['title'] ?? 'N/A'; ?></h1>
        <span class="mt-2 text-sm text-center text-white">
          Semua chapter komik<a class="text-blue-500" href="<?=$data['data']['allChaptersLink'] ?? '#'; ?>"><?= preg_replace('/Komik|Chapter \d+/', '', $data['data']['title'] ?? 'N/A'); ?></a>
        </span>
      </div>
      <div class="flex flex-col gap-y-4 sm:flex-row justify-between my-6">
        <div class="flex items-center justify-between gap-x-2">
          <?php if (!empty($data['data']['prevChapterLink'])): ?>
          <a href="/chapter<?=$data['data']['prevChapterLink']; ?>">
            <button class="prev relative inline-flex gap-x-1.5 items-center px-4 py-1.5 text-sm font-medium rounded-full bg-violet-900 border border-gray-700 text-white hover:bg-violet-700 transition ease-in-out duration-150">
              <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" class="w-5 h-5">
                <path fill-rule="evenodd" d="M11.78 5.22a.75.75 0 0 1 0 1.06L8.06 10l3.72 3.72a.75.75 0 1 1-1.06 1.06l-4.25-4.25a.75.75 0 0 1 0-1.06l4.25-4.25a.75.75 0 0 1 1.06 0Z" clip-rule="evenodd"></path>
              </svg>
              Prev
            </button>
          </a>
          <?php endif; ?>
          <?php if (!empty($data['data']['nextChapterLink'])): ?>
          <a href="/chapter<?=$data['data']['nextChapterLink']; ?>">
            <button class="next relative inline-flex gap-x-1.5 items-center px-4 py-1.5 text-sm font-medium rounded-full bg-violet-900 border border-gray-700 text-white hover:bg-violet-700 transition ease-in-out duration-150">
              Next
              <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" class="w-5 h-5">
                <path fill-rule="evenodd" d="M8.22 5.22a.75.75 0 0 1 1.06 0l4.25 4.25a.75.75 0 0 1 0 1.06l-4.25 4.25a.75.75 0 0 1-1.06-1.06L11.94 10 8.22 6.28a.75.75 0 0 1 0-1.06Z" clip-rule="evenodd"></path>
              </svg>
            </button>
          </a>
          <?php endif; ?>
        </div>
      </div>
      <div class="max-w-5xl -mx-4 sm:mx-auto text-center relative">
        <?php if (!empty($data['data']['images'])): ?>
        <?php foreach ($data['data']['images'] as $image): ?>
        <img src="/i?url=<?=$image; ?>" class="max-w-full mx-auto my-0 block" alt="<?=$data['data']['title'] ?? 'N/A'; ?>" loading="lazy" decoding="async">
        <?php endforeach; ?>
        <?php else : ?>
        <p>
          No images available
        </p>
        <?php endif; ?>
      </div>
      <div class="flex flex-col gap-y-4 sm:flex-row justify-between my-6">
        <div class="flex items-center justify-between gap-x-2">
          <?php if (!empty($data['data']['prevChapterLink'])): ?>
          <a href="/chapter<?=$data['data']['prevChapterLink']; ?>">
            <button class="prev relative inline-flex gap-x-1.5 items-center px-4 py-1.5 text-sm font-medium rounded-full bg-violet-900 border border-gray-700 text-white hover:bg-violet-700 transition ease-in-out duration-150">
              <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" class="w-5 h-5">
                <path fill-rule="evenodd" d="M11.78 5.22a.75.75 0 0 1 0 1.06L8.06 10l3.72 3.72a.75.75 0 1 1-1.06 1.06l-4.25-4.25a.75.75 0 0 1 0-1.06l4.25-4.25a.75.75 0 0 1 1.06 0Z" clip-rule="evenodd"></path>
              </svg>
              Prev
            </button>
          </a>
          <?php endif; ?>
          <?php if (!empty($data['data']['nextChapterLink'])): ?>
          <a href="/chapter<?=$data['data']['nextChapterLink']; ?>">
            <button class="next relative inline-flex gap-x-1.5 items-center px-4 py-1.5 text-sm font-medium rounded-full bg-violet-900 border border-gray-700 text-white hover:bg-violet-700 transition ease-in-out duration-150">
              Next
              <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" class="w-5 h-5">
                <path fill-rule="evenodd" d="M8.22 5.22a.75.75 0 0 1 1.06 0l4.25 4.25a.75.75 0 0 1 0 1.06l-4.25 4.25a.75.75 0 0 1-1.06-1.06L11.94 10 8.22 6.28a.75.75 0 0 1 0-1.06Z" clip-rule="evenodd"></path>
              </svg>
            </button>
          </a>
          <?php endif; ?>
        </div>
      </div>
      <div class="my-6">
        <p class="text-sm text-center text-white">
          <?=$data['data']['shortDescription'] ?? 'N/A'; ?>
        </p>
      </div>
    </main>
    <?php include('inc/footer.php'); ?>
  </div>
</body>
</html>