<?php

$request_uri = $_SERVER['REQUEST_URI'];
$page = explode('/', $request_uri);
$anime_info = isset($page[2]) ? rtrim($page[2], '/') : '';

// File cache
$cacheDuration = 3600; // 1 jam
$cacheFile = 'cache/nonton/' . md5($anime_info) . '.json'; // Nama file cache berdasarkan hash endpoint

// Fungsi untuk mengambil data dari API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Fungsi untuk mendapatkan data dari cache atau API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();

  // Jika file cache ada dan masih berlaku
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Ambil data dari API dan simpan ke cache
  $data = fetchData($apiUrl);
  if (isset($data['status']) && $data['status'] === true) {
    file_put_contents($cacheFile, json_encode($data));
  }

  return $data;
}

// Tentukan URL API untuk endpoint
$apiUrl = "$api/api/anime/nonton/$anime_info";

// Ambil data dengan caching
$data = getData($cacheFile, $apiUrl, $cacheDuration);

// Tampilkan data
?>
<html lang="en" class="dark text-foreground bg-background" style="">

<head>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="theme-color" content="#05010d">
  <meta charset="utf-8">
  <title>Episode <?= $data['data']['episodeNumber'] ?? 'N/A' ?> - <?= $data['data']['judul'] ?? 'N/A' ?> | <?=$site_TITLE ?> - Nonton Anime Subtitle Indonesia</title>
  <meta name="description" content="<?= htmlspecialchars(substr($data['data']['description'] ?? 'Tonton dan download anime episode terbaru, subtitle Indonesia, streaming anime kualitas terbaik hanya di ' . $site_TITLE . '. Nikmati koleksi anime terbaru dan populer di sini.', 0, 150)) . (strlen($data['data']['description'] ?? '') > 150 ? '...' : '') ?> | <?=$site_TITLE?>">
  <meta name="application-name" content="<?=$site_TITLE ?>">
  <link rel="canonical" href="<?=$siteURL ?>/episode/<?=$anime_info ?>" />
  <link rel="manifest" href="/manifest.json" crossorigin="use-credentials">
  <meta name="keywords" content="nonton anime, download anime, streaming anime, episode anime terbaru, anime subtitle Indonesia, anime populer, anime terbaru, Aniplay, Kiryuu.cc, Komikindo, Mangaku, Baca manga, Samehadaku, Mangatoon, Komikcast, Otakudesu, Komikindo.web.id, Mangakita, Komiku, Manganime, Bacamanga.cc, Komikidn, Mangakita.net, Komikstation.com, Kaizo.fun">
  <meta name="format-detection" content="telephone=no">
  <meta name="apple-mobile-web-app-capable" content="yes">
  <meta name="apple-mobile-web-app-title" content="<?=$site_TITLE?> - Nonton Anime Online">
  <meta name="apple-mobile-web-app-status-bar-style" content="default">
  <meta property="og:url" content="<?=$siteURL ?>/episode/<?=$anime_info ?>" />
  <meta property="og:title" content="Episode <?= $data['data']['episodeNumber'] ?? 'N/A' ?> - <?= $data['data']['judul'] ?? 'N/A' ?> | <?=$site_TITLE ?>">
  <meta property="og:description" content="<?= htmlspecialchars(substr($data['data']['description'] ?? 'Tonton dan download anime episode terbaru, subtitle Indonesia, streaming anime kualitas terbaik hanya di ' . $site_TITLE . '. Nikmati koleksi anime terbaru dan populer di sini.', 0, 150)) . (strlen($data['data']['description'] ?? '') > 150 ? '...' : '') ?> | <?=$site_TITLE?>">
  <meta property="og:image" content="<?= $data['data']['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>">
  <meta name="twitter:card" content="summary">
  <meta name="twitter:title" content="Episode <?= $data['data']['episodeNumber'] ?? 'N/A' ?> - <?= $data['data']['judul'] ?? 'N/A' ?> | <?=$site_TITLE ?>">
  <meta name="twitter:description" content="<?= htmlspecialchars(substr($data['data']['description'] ?? 'Tonton dan download anime episode terbaru, subtitle Indonesia, streaming anime kualitas terbaik hanya di ' . $site_TITLE . '. Nikmati koleksi anime terbaru dan populer di sini.', 0, 150)) . (strlen($data['data']['description'] ?? '') > 150 ? '...' : '') ?> | <?=$site_TITLE?>">
  <meta name="twitter:image" content="<?= $data['data']['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>">
  <link rel="shortcut icon" href="/favicon-16x16.png">
  <link rel="apple-touch-icon" href="/apple-touch-icon.png">
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy2.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy3.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy4.css" />
  <script src="https://cdn.tailwindcss.com"></script>
  <meta name="next-size-adjust">
  <link rel="preconnect" href="https://cdn.jsdelivr.net/npm/hls.js@^1.5.0/dist/hls.min.js" crossorigin="true">
  <script src="https://cdn.jsdelivr.net/npm/hls.js@^1.5.0/dist/hls.min.js"></script>
  
  <style>
    #komekkovid {
      margin: auto;
      overflow: hidden;
      box-shadow: 0 2px 6px -1px rgb(7 10 25 / 5%), 0 6px 12px -6px rgb(7 10 25 / 10%);
      border-radius: 8px;
    }
    .lazy-v {
      position: relative;
      width: 100%;
      height: 0;
      padding-bottom: 56.25%;
      background-color: #000;
      cursor: pointer;
      overflow: hidden;
    }
    #komekkovid .lazy-v p {
      color: #fff;
      display: flex;
      justify-content: center;
    }
    .lazy-v iframe, .lazy-v img, .play {
      position: absolute;
    }
    .play {
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      width: 60px;
      height: 60px;
      background-color: rgba(0,0,0,.7);
      border-radius: 50%;
      display: flex;
      justify-content: center;
      align-items: center;
    }
    .play span {
      border-style: solid;
      border-width: 15px 0 15px 26.7px;
      border-color: transparent transparent transparent #fff;
      margin-left: 5px;
    }
    .lazy-v img {
      top: 0;
      left: 0;
      width: calc(100% + 5px);
      border: 0;
      border-radius: 0;
      opacity: .95;
      z-index: -1;
    }
    .lazy-v iframe {
      bottom: 0;
      right: 0;
      width: 100%;
      height: 100%;
    }
    .servideo {
      display: flex;
      flex-wrap: wrap;
      gap: 10px;
      padding: 12px;
      font-size: 13px;
    }
    .servideo .change-video {
      background-color: #222;
      color: #eee;
      border-radius: 4px;
      padding: 4px 10px;
      cursor: pointer;
      align-items: center;
      display: flex;
      transition: .4s;
    }
    .servideo .change-video.c-aktif, .servideo .change-video:hover {
      background: rgb(99 77 235);
      transition: .4s;
    }
    .servideo .change-video:before {
      content: "";
      opacity: 0;
    }
    .servideo .change-video.c-aktif:before {
      content: "";
      margin-right: 5px;
      margin-left: -5px;
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'%3E%3Ctitle%3Eplay-circle%3C/title%3E%3Cpath d='M10,16.5V7.5L16,12M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z' fill='%23fff' /%3E%3C/svg%3E");
      width: 18px;
      height: 18px;
      display: inline-block;
      transition: .3s;
      opacity: 1;
    }
    .servideo select {
      background-color: #222;
      color: #eee;
      border-radius: 4px;
      padding: 4px 10px;
      cursor: pointer;
      display: flex;
      transition: .4s;
      outline: none;
      border: 0;
    }
    .servideo select:focus, .servideo select:hover {
      background: rgb(99 77 235);
      transition: .4s;
    }
  </style>
</head>

<body class="__className_7df6af">
  <div>
    <?php
    include('inc/navbar.php')
    ?>
    <div class="w-screen max-w-full lg:max-w-[98%] mx-auto overflow-hidden lg:pl-14 min-h-screen">
      <main class="flex flex-col gap-5">
        <div class="flex flex-col lg:flex-row mt-[72px] lg:mt-[80px] gap-5">
          <div class="w-full aspect-video flex flex-col">
            <div class="w-full flex flex-col">
              <div class="">
                <div id="komekkovid">
                  <div class='lazy-v' data-embed='' style='z-index: 1;'>
                    <div class='play'>
                      <span></span>
                    </div>
                    <img class='thumb-v' src='<?= $data['data']['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>' alt='Video Thumbnail'>
                  </div>
                </div>
                <!-- player cuy-->
              </div>
              <div class="">
                <div class="mx-1 px-1 lg:px-0">
                  <h2 class="text-[20px] opacity-90 font-semibold line-clamp-1 lg:w-[75%]"><?= $data['data']['judul'] ?? 'N/A' ?></h2>
                  <div class="flex flex-row justify-between items-center w-full">
                    <h2 class="text-[17px] text-textsec font-medium "> EPISODE <?= $data['data']['episodeNumber'] ?? 'N/A' ?> </h2>
                    <div class=" right-0 flex flex-row gap-3">
                      <button type="button" id="openPopup" class="flex px-4 py-1 rounded items-center gap-1 bg-boxbg">
                        <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 20 20">
                          <path fill="currentColor" fill-rule="evenodd" d="M3 17a1 1 0 0 1 1-1h12a1 1 0 1 1 0 2H4a1 1 0 0 1-1-1m3.293-7.707a1 1 0 0 1 1.414 0L9 10.586V3a1 1 0 1 1 2 0v7.586l1.293-1.293a1 1 0 1 1 1.414 1.414l-3 3a1 1 0 0 1-1.414 0l-3-3a1 1 0 0 1 0-1.414"
                            clip-rule="evenodd"></path>
                        </svg><span class="hidden lg:block font-medium text-sm">Download</span></button>
                    </div>
                  </div>
                </div>
                <div class="border-t border-solid border-gray-300 my-4 border-opacity-10"></div>
                <div class="mx-auto w-full max-w-[98%] lg:max-w-[99%] h-[100px]">
                  <div class="rounded-lg flex flex-row items-center gap-2 h-full">
                    <div class="hidden md:flex flex-col p-4 items-center justify-center rounded-lg bg-boxbg flex-grow h-full">
                      <span class="text-xs xl:text-sm text-textsec">Kamu menonton </span><span class="font-medium text-sm md:text-white">Episode <?= $data['data']['episodeNumber'] ?? 'N/A' ?></span><span class="!leading-tight text-xs xl:text-sm flex flex-col items-center justify-center text-center text-textsec">Coba server lain di dropdown jika server error.</span>
                    </div>
                    <div
                      class="flex flex-col gap-4 h-full items-center justify-center py-3 xxs:px-8 w-full md:w-fit md:flex-shrink-0 bg-boxbg rounded-lg">
                      <div class="flex flex-row flex-wrap items-center xxs:gap-5 gap-2">
                        <span class="flex flex-row items-center gap-1 font-medium ">
                          <svg fill="#000000"class="w-5 h-5 fill-[#FFFFFF]" fill="none" aria-hidden="true" focusable="false" version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                            viewBox="0 0 511 511" xml:space="preserve">
                            <g>
                              <path d="M471.5,167c21.78,0,39.5-17.72,39.5-39.5v-64c0-21.78-17.72-39.5-39.5-39.5h-432C17.72,24,0,41.72,0,63.5v64
                                C0,149.28,17.72,167,39.5,167H248v17H39.5C17.72,184,0,201.72,0,223.5v64C0,309.28,17.72,327,39.5,327H248v17H39.5
                                C17.72,344,0,361.72,0,383.5v64C0,469.28,17.72,487,39.5,487h432c21.78,0,39.5-17.72,39.5-39.5v-64c0-21.78-17.72-39.5-39.5-39.5
                                H263v-17h208.5c21.78,0,39.5-17.72,39.5-39.5v-64c0-21.78-17.72-39.5-39.5-39.5H263v-17H471.5z M496,383.5v64
                                c0,13.51-10.991,24.5-24.5,24.5h-432C25.991,472,15,461.01,15,447.5v-64c0-13.51,10.991-24.5,24.5-24.5h432
                                C485.009,359,496,369.99,496,383.5z M496,223.5v64c0,13.51-10.991,24.5-24.5,24.5h-432C25.991,312,15,301.01,15,287.5v-64
                                c0-13.51,10.991-24.5,24.5-24.5h432C485.009,199,496,209.99,496,223.5z M15,127.5v-64C15,49.99,25.991,39,39.5,39h432
                                c13.509,0,24.5,10.99,24.5,24.5v64c0,13.51-10.991,24.5-24.5,24.5h-432C25.991,152,15,141.01,15,127.5z" />
                              <path d="M71.5,64C54.131,64,40,78.131,40,95.5S54.131,127,71.5,127S103,112.869,103,95.5S88.869,64,71.5,64z M71.5,112
                                c-9.098,0-16.5-7.402-16.5-16.5S62.402,79,71.5,79S88,86.402,88,95.5S80.598,112,71.5,112z" />
                              <path d="M143.5,72C130.542,72,120,82.542,120,95.5s10.542,23.5,23.5,23.5S167,108.458,167,95.5S156.458,72,143.5,72z M143.5,104
                                c-4.687,0-8.5-3.813-8.5-8.5s3.813-8.5,8.5-8.5s8.5,3.813,8.5,8.5S148.187,104,143.5,104z" />
                              <path d="M71.5,224C54.131,224,40,238.131,40,255.5S54.131,287,71.5,287s31.5-14.131,31.5-31.5S88.869,224,71.5,224z M71.5,272
                                c-9.098,0-16.5-7.402-16.5-16.5S62.402,239,71.5,239S88,246.402,88,255.5S80.598,272,71.5,272z" />
                              <path d="M143.5,232c-12.958,0-23.5,10.542-23.5,23.5s10.542,23.5,23.5,23.5s23.5-10.542,23.5-23.5S156.458,232,143.5,232z
                                M143.5,264c-4.687,0-8.5-3.813-8.5-8.5s3.813-8.5,8.5-8.5s8.5,3.813,8.5,8.5S148.187,264,143.5,264z" />
                              <path d="M455.5,264h-264c-4.142,0-7.5,3.357-7.5,7.5s3.358,7.5,7.5,7.5h264c4.142,0,7.5-3.357,7.5-7.5S459.642,264,455.5,264z" />
                              <path d="M184,239.5c0,4.143,3.358,7.5,7.5,7.5h264c4.142,0,7.5-3.357,7.5-7.5s-3.358-7.5-7.5-7.5h-264
                                C187.358,232,184,235.357,184,239.5z" />
                              <path d="M463,111.5c0-4.143-3.358-7.5-7.5-7.5h-264c-4.142,0-7.5,3.357-7.5,7.5s3.358,7.5,7.5,7.5h264
                                C459.642,119,463,115.643,463,111.5z" />
                              <path d="M191.5,87h264c4.142,0,7.5-3.357,7.5-7.5s-3.358-7.5-7.5-7.5h-264c-4.142,0-7.5,3.357-7.5,7.5S187.358,87,191.5,87z" />
                              <path d="M71.5,384C54.131,384,40,398.131,40,415.5S54.131,447,71.5,447s31.5-14.131,31.5-31.5S88.869,384,71.5,384z M71.5,432
                                c-9.098,0-16.5-7.402-16.5-16.5S62.402,399,71.5,399S88,406.402,88,415.5S80.598,432,71.5,432z" />
                              <path d="M143.5,392c-12.958,0-23.5,10.542-23.5,23.5s10.542,23.5,23.5,23.5s23.5-10.542,23.5-23.5S156.458,392,143.5,392z
                                M143.5,424c-4.687,0-8.5-3.813-8.5-8.5s3.813-8.5,8.5-8.5s8.5,3.813,8.5,8.5S148.187,424,143.5,424z" />
                              <path d="M455.5,424h-264c-4.142,0-7.5,3.357-7.5,7.5s3.358,7.5,7.5,7.5h264c4.142,0,7.5-3.357,7.5-7.5S459.642,424,455.5,424z" />
                              <path d="M184,399.5c0,4.143,3.358,7.5,7.5,7.5h264c4.142,0,7.5-3.357,7.5-7.5s-3.358-7.5-7.5-7.5h-264
                                C187.358,392,184,395.357,184,399.5z" />
                            </g>
                          </svg>SERVER : </span>
                        <select id="videoSelector" class="outline-none capitalize px-3 py-1 w-fit h-fit text-xs lg:text-sm cursor-pointer text-white/95 font-medium tracking-wide rounded bg-buttonp">
                          <optgroup label="server">
                            <?php if (isset($data['data']['video'])): ?>
                            <?php foreach ($data['data']['video'] as $video): ?>
                            <option value="<?= $video['src'] ?? '#' ?>"><?= $video['server'] ?? 'Unknown' ?></option>

                            <?php endforeach; ?>
                            <?php else : ?>
                            <option value="">Not available</option>
                            <?php endif; ?>
                          </optgroup>
                        </select>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="mx-2 lg:mx-1 mt-4 border-opacity-10">
                  <div class="flex text-[13px] bg-boxbg py-2 rounded-lg text-center px-3 text-[#ffffffb2] flex-row gap-1 sm:items-center justify-center">
                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5">
                      <path stroke-linecap="round" stroke-linejoin="round" d="M10.34 15.84c-.688-.06-1.386-.09-2.09-.09H7.5a4.5 4.5 0 1 1 0-9h.75c.704 0 1.402-.03 2.09-.09m0 9.18c.253.962.584 1.892.985 2.783.247.55.06 1.21-.463 1.511l-.657.38c-.551.318-1.26.117-1.527-.461a20.845 20.845 0 0 1-1.44-4.282m3.102.069a18.03 18.03 0 0 1-.59-4.59c0-1.586.205-3.124.59-4.59m0 9.18a23.848 23.848 0 0 1 8.835 2.535M10.34 6.66a23.847 23.847 0 0 0 8.835-2.535m0 0A23.74 23.74 0 0 0 18.795 3m.38 1.125a23.91 23.91 0 0 1 1.014 5.395m-1.014 8.855c-.118.38-.245.754-.38 1.125m.38-1.125a23.91 23.91 0 0 0 1.014-5.395m0-3.46c.495.413.811 1.035.811 1.73 0 .695-.316 1.317-.811 1.73m0-3.46a24.347 24.347 0 0 1 0 3.46"></path>
                    </svg><a href="<?=$trakteer ?>">Trakteer bang🗿</a>
                  </div>
                </div>
              </div>
            </div>

          </div>

          <div class="lg:w-[580px] mx-2 lg:mx-0 !lg:mr-4">
            <div class="w-full">
              <div class="PlayerEpisodeList_episodebottom__nsmaj">
                <div class="Episodesection_epleft__ReCcn">
                  <div class="flex items-center gap-2">
                    <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                    <h1 class="text-[19px] sm:text-[22px] font-medium md:font-semibold">Episode</h1>
                  </div>
                </div>
                <div class="mt-3">
                  <div class="flex flex-col lg:gap-0.5 max-h-[22.5rem] lg:max-h-[750px] overflow-y-scroll scrollbar-hide">
                    <?php if (isset($data['data']['episodes'])): ?>
                    <?php foreach ($data['data']['episodes'] as $episode): ?>
                    <a class="flex flex-row items-center transition-all duration-300 ease-out hover:scale-[0.975] hover:bg-[#27272c] rounded-xl my-[5px] bg-boxbg h-20 lg:h-[5.5rem] gap-3  " href="<?= $episode['link'] ?? '#' ?>">
                      <div class="flex relative flex-shrink-0 h-full items-center rounded-xl overflow-hidden aspect-[15/9]">
                        <img alt="Losing the Battle Before It Is Ever Fought" loading="lazy" width="160" height="200" decoding="async" data-nimg="1" class="h-full aspect-[15/9] relative rounded-xl overflow-hidden flex-shrink-0 object-cover !brightness-95"
                        src="<?= $episode['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>" style="color: transparent;">
                        <div class="absolute bottom-0 left-0 w-full rounded-lg z-10">
                          <hr class="border-red-600 !border-[.10rem] rounded-lg" style="width: 0%;">
                        </div>
                      </div>
                      <div class="flex flex-col gap-1 pr-1">
                        <div class="line-clamp-1 text-sm  opacity-90 font-semibold">
                          <?= $episode['judul'] ?? 'No Title' ?>
                        </div>
                        <div class="line-clamp-2 text-xs text-textsec opacity-70 font-normal">
                          No deskripsi
                        </div>
                      </div>
                    </a>
                    <?php endforeach; ?>
                    <?php else : ?>
                    <li>No episodes data available.</li>
                    <?php endif; ?>

                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
        <div class="">
          <div class="py-2 md:py-2 px-2 mx-4 lg:mx-2 lg:px-0 border-t border-solid border-gray-300 border-opacity-10"></div>
        </div>
        <div class="flex gap-2">
          <div class="flex w-full h-fit flex-col">
            <div class="px-3 md:pl-2 xl:pl-1 flex md:flex-row gap-3 md:gap-5 w-full rounded-lg">
              <div class="object-cover aspect-[8/12.5] sm:aspect-[8/11.5] h-[187px] sm:h-[240px] relative flex-shrink-0 mx-auto sm:m-0 overflow-hidden rounded-md bg-boxbg">
                <img alt="Anime" loading="lazy" width="200" height="200" decoding="async" data-nimg="1" class="w-full h-full object-cover" src="<?= $data['data']['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>" alt="<?= $data['data']['altJudul'] ?? 'No Title' ?>" style="color: transparent;">
              </div>
              <div
                class="flex flex-col gap-3 flex-grow">
                <div class="flex flex-col relative justify-between gap-2">
                  <div class="font-medium text-lg flex flex-row justify-between gap-1">
                    <a previewlistener="true" class="" href="<?= $data['data']['allEpisode'] ?? 'N/A' ?>"><span class="font-semibold opacity-90 !line-clamp-2 tracking-wide text-[17px] sm:!text-[20px] !leading-snug w-full mr-2"><?= $data['data']['judul'] ?? 'N/A' ?></span></a>
                    <div class="flex gap-3 h-fit ml-2">
                      <button title="Share link" class="h-fit relative border-none outline-none">
                        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="2.5" stroke="currentColor" class="w-[18px] h-[18px] sm:w-5 sm:h-5">
                          <path stroke-linecap="round" stroke-linejoin="round" d="M7.217 10.907a2.25 2.25 0 1 0 0 2.186m0-2.186c.18.324.283.696.283 1.093s-.103.77-.283 1.093m0-2.186 9.566-5.314m-9.566 7.5 9.566 5.314m0 0a2.25 2.25 0 1 0 3.935 2.186 2.25 2.25 0 0 0-3.935-2.186Zm0-12.814a2.25 2.25 0 1 0 3.933-2.185 2.25 2.25 0 0 0-3.933 2.185Z"></path>
                        </svg>
                      </button>
                      <div class="w-fit flex relative h-fit">
                        <button title="Edit List" class="h-fit border-none outline-none">
                          <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 sm:w-[22px] sm:h-[22px]" viewBox="0 0 24 24" fill="white" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                            <path d="m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z"></path>
                          </svg>
                        </button>
                      </div>
                    </div>
                  </div>
                </div>
                <div class="">
                  <div class="font-medium tracking-wide sm:tracking-wider !text-xs sm:text-sm flex flex-col gap-1.5 !capitalize">
                    <p>
                      <span class="">Type: </span><span class="text-textsec"><?= $data['data']['detail']['Jenis'] ?? 'N/A' ?></span>
                    </p>
                    <p>
                      <span class="">Status: </span><span class="text-textsec"><?= $data['data']['detail']['Status'] ?? 'N/A' ?></span>
                    </p>
                    <p>
                      <span class="">Season: </span><span class="text-textsec"><?= $data['data']['detail']['Musim']['text'] ?? 'N/A' ?></span>
                    </p>
                    <p>
                      <span class="">Duration: </span><span class="text-textsec "><?= $data['data']['detail']['Durasi'] ?? 'N/A' ?></span>
                    </p>
                    <p>
                      <span class="">Pengarang: </span><span class="text-textsec "><?= $data['data']['detail']['Pengarang']['text'] ?? 'N/A' ?></span>
                    </p>
                    <p>
                      <span class="">Kredit: </span><span class="text-textsec "><a href="https://tv.animisme.net/<?=$anime_info ?>">animisme.net</a></span>
                    </p>
                  </div>
                  <div class="flex-wrap gap-3 mt-4 hidden sm:flex">
                    <?php if (isset($data['data']['genres'])): ?>
                    <?php foreach ($data['data']['genres'] as $genre): ?>
                    <a class="!px-2 py-1 !w-auto text-center text-sm text-gray-100 hover:brightness-150 font-normal ring-1 ring-buttonp rounded-md" href="<?= $genre['link'] ?? '#' ?>"><?= $genre['genre'] ?? 'No Genre' ?></a>
                    <?php endforeach; ?>
                    <?php else : ?>
                    <a class="!px-2 py-1 !w-auto text-center text-sm text-gray-100 hover:brightness-150 font-normal ring-1 ring-buttonp rounded-md">No Genre</a>
                    <?php endif; ?>
                  </div>
                </div>
              </div>
            </div>
            <div class="flex-wrap gap-3 ml-3 mt-4 flex sm:hidden">
              <?php if (isset($data['data']['genres'])): ?>
              <?php foreach ($data['data']['genres'] as $genre): ?>
              <a class="!px-2 py-1 !w-auto text-center text-sm text-gray-100 hover:brightness-150 font-normal ring-1 ring-buttonp rounded-md"href="<?= $genre['link'] ?? '#' ?>"><?= $genre['genre'] ?? 'No Genre' ?></a>
              <?php endforeach; ?>
              <?php else : ?>
              <a class="!px-2 py-1 !w-auto text-center text-sm text-gray-100 hover:brightness-150 font-normal ring-1 ring-buttonp rounded-md">Not available</a>
              <?php endif; ?>
            </div>
            <div class="flex flex-col bg-boxbg px-5 rounded-md py-4 my-3 mx-3 lg:mx-1 justify-center">
              <div class="hidden lg:block w-full">
                <span class="w-full text-textsec text-sm"><?= $data['data']['description'] ?? 'N/A' ?></span>

              </div>
              <div class="block lg:hidden w-full">
                <span class="w-full text-textsec text-sm"><?= $data['data']['description'] ?? 'N/A' ?></span>
              </div>
            </div>
          </div>
        </div>
      </main>
      <div class="lg:px-2 my-2">
        <div class="my-2 md:my-4">
          <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
            <div class="flex items-center gap-2 px-3 xl:px-0">
              <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
              <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Rekomen</h1>
            </div>
            <div class="relative">
              <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full "><svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4"><path d="m15 18-6-6 6-6"></path></svg></span>
              <span
                class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
                <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                  <path d="m9 18 6-6-6-6"></path>
                </svg>
              </span>
              <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0" id="Recommendations" style="cursor: auto;">
                <?php
                // Check if data is valid and recommendations exist
                if (isset($data['status']) && $data['status'] === true && isset($data['data']['recommendations']) && !empty($data['data']['recommendations'])):
                foreach ($data['data']['recommendations'] as $rec): ?>
                <a href="<?php echo htmlspecialchars($rec['link']); ?>" style="cursor: pointer;">
                  <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                    <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                      <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                        <img alt="Chuunibyou demo Koi ga Shitai! Ren" loading="eager" width="155" height="230" decoding="async" data-nimg="1" class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105"
                        src="<?php echo htmlspecialchars($rec['img']); ?>" style="color: transparent;">
                      </div>
                      <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                        <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                          <span class="uppercase"><?php echo htmlspecialchars($rec['type']); ?></span> <span class="text-[10px]">•</span><span class="font-semibold text-white"><?php echo htmlspecialchars($rec['epx']); ?></span>
                        </div>
                      </div>
                    </div>
                    <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2"><span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full hidden xl:hidden"></span>Chuunibyou
                      <?php echo htmlspecialchars($rec['title']); ?></span>
                  </div>
                </a>
                <?php endforeach; ?>
                <?php else : ?>
                <p>
                error fetch api cuk
                </p>
                <?php endif; ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
    <!-- Popup Box -->
    <div id="popupBox" class="fixed inset-0 flex items-center justify-center bg-black/50 backdrop-blur-sm z-50 hidden">
      <div class="relative bg-[#17171c] shadow-md shadow-black/70 rounded-xl transition-all py-3 scale-100 opacity-100">
        <!-- Tombol untuk menutup popup -->
        <button id="closePopup" class="absolute top-2 right-2 p-1 rounded-lg text-gray-400 bg-content1 hover:text-white">
          <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 15 15">
            <path fill="currentColor" d="M3.64 2.27L7.5 6.13l3.84-3.84A.92.92 0 0 1 12 2a1 1 0 0 1 1 1a.9.9 0 0 1-.27.66L8.84 7.5l3.89 3.89A.9.9 0 0 1 13 12a1 1 0 0 1-1 1a.92.92 0 0 1-.69-.27L7.5 8.87l-3.85 3.85A.92.92 0 0 1 3 13a1 1 0 0 1-1-1a.9.9 0 0 1 .27-.66L6.16 7.5L2.27 3.61A.9.9 0 0 1 2 3a1 1 0 0 1 1-1c.24.003.47.1.64.27"></path>
          </svg>
        </button>
        <!-- Download menu -->
        <div class="px-5 w-80 sm:w-96 mx-4 mb-4">
          <div class="h-[3rem] pt-3 border-b border-white/10 text-xl font-medium pb-1">
            Pilih server download...
          </div>
          <div class="flex flex-col gap-4 my-5">
            <?php if (isset($data['data']['serverdl'])): ?>
            <?php foreach ($data['data']['serverdl'] as $server): ?>
            <?php foreach ($server['links'] as $link): ?>
            <a target="_blank" class="flex flex-row justify-between py-3 px-5 bg-[#232328] transition-all hover:bg-opacity-40 rounded-md" href="http://adfoc.us/serve/sitelinks/?id=865214&url=<?= $link['url'] ?? '#' ?>">
              <span class="font-medium opacity-90"><?= $server['server'] ?? 'Unknown' ?></span>
              <span class="text-textsec text-sm font-medium"><?= $link['text'] ?? 'No Text' ?></span>
            </a>
            <?php endforeach; ?>
            <?php endforeach; ?>
            <?php else : ?>
            <p class="flex flex-row justify-between py-3 px-5 bg-[#232328] transition-all hover:bg-opacity-40 rounded-md">
              <span class="font-medium opacity-90">Not available</span>
            </p>
            <?php endif; ?>
          </div>
        </div>
      </div>
    </div>
    <?php include('inc/footer.php'); ?>
  </div>
  <script>
    const popupBox = document.getElementById('popupBox');
    const openPopup = document.getElementById('openPopup');
    const closePopup = document.getElementById('closePopup');
    // Fungsi untuk menampilkan popup
    const showPopup = () => {
      popupBox.classList.remove('hidden');
    };
    // Fungsi untuk menyembunyikan popup
    const hidePopup = () => {
      popupBox.classList.add('hidden');
    };
    // Event listener untuk membuka popup saat tombol ditekan
    openPopup.addEventListener('click', showPopup);
    // Event listener untuk menutup popup saat klik tombol close
    closePopup.addEventListener('click', hidePopup);
    // Event listener untuk menutup popup saat klik di luar box
    popupBox.addEventListener('click', (e) => {
      if (e.target === popupBox) {
        hidePopup();
      }
    });
    document.addEventListener("DOMContentLoaded", function() {
      var thumbnail = "<?= $data['data']['gambar'] ?? 'https://i.ibb.co.com/WKb7b2s/Itsuki.jpg' ?>";
      // Handle thumbnail and play button click
      document.querySelectorAll(".lazy-v").forEach(function(e) {
        var embedURL = e.getAttribute("data-embed"),
        playButton = e.querySelector(".play"),
        thumbnailImage = e.querySelector(".thumb-v");

        playButton.addEventListener("click", function() {
          if (!embedURL) {
            var activeOption = document.querySelector("#videoSelector option:checked");
            embedURL = activeOption ? activeOption.value: "";
          }
          if (embedURL) {
            e.innerHTML = '<iframe src="' + embedURL + '" frameborder="0" allowfullscreen="true" webkitallowfullscreen="true" mozallowfullscreen="true" height="100%"" scrolling="no" width="100%"></iframe>';
          }
        });

        thumbnailImage.src = thumbnail;
        thumbnailImage.onerror = function() {
          thumbnailImage.remove();
          var errorMsg = document.createElement("p");
          errorMsg.textContent = "Thumbnail tidak dapat dimuat.";
          e.appendChild(errorMsg);
        };
      });

      // Handle select dropdown change
      var videoSelector = document.getElementById("videoSelector");
      videoSelector.addEventListener("change", function() {
        var embedURL = this.value,
        lazyVContainer = document.querySelector(".lazy-v"),
        iframeElement = document.createElement("iframe");

        iframeElement.src = embedURL;
        iframeElement.frameBorder = "0";
        iframeElement.allowfullscreen = "true";
        iframeElement.setAttribute("allow",
          "fullscreen");
        iframeElement.webkitallowfullscreen = "true";
        iframeElement.mozallowfullscreen = "true";

        lazyVContainer.innerHTML = "";
        lazyVContainer.appendChild(iframeElement);
      });
    });
  </script>
  
</body>

</html>