<?php
// URL API
$animeApi = "$api/api/anime/latest";
$komikApi = "$api/api/komik/latest/1";

// Durasi cache
$cacheDuration = 18000; // 5 jam dalam detik

// File cache
$animeCacheFile = 'cache/cache_anime.json';
$komikCacheFile = 'cache/cache_komik.json';

// Fungsi untuk mengambil data dari API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Fungsi untuk mendapatkan data dari cache atau API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();
  // Periksa apakah file cache ada dan masih berlaku
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Ambil data dari API dan periksa statusnya
  do {
    $data = fetchData($apiUrl);
    if ($data['status'] === true) {
      // Simpan data ke file cache jika statusnya true
      file_put_contents($cacheFile, json_encode($data));
      break;
    }
    // Tunggu sebelum mencoba lagi (misalnya 1 detik)
    sleep(1);
  } while (true);

  return $data;
}

// Ambil data dengan caching
$animeData = getData($animeCacheFile, $animeApi, $cacheDuration);
$komikData = getData($komikCacheFile, $komikApi, $cacheDuration);
?>

<html lang="en" class="dark text-foreground bg-background">
<head>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1" />
  <meta name="theme-color" content="#05010d" />
  <title><?=$site_TITLE ?> - Nonton Anime dan Komik Terbaru Setiap Hari</title>
  <meta name="description" content="Temukan dunia anime dan komik tanpa gangguan di <?=$site_TITLE ?>! Nikmati seri favorit Anda secara gratis, tanpa iklan yang mengganggu pengalaman menonton Anda. Bergabunglah sekarang untuk update anime dan komik terbaru setiap hari di <?=$site_TITLE ?>!" />
  <meta name="application-name" content="<?=$site_TITLE ?>" />
  <link rel="manifest" href="/manifest.json" crossorigin="use-credentials" />
  <meta name="keywords" content="anime, komik, streaming anime, streaming komik, anime terbaru, komik terbaru, anime populer, komik populer, situs anime Indonesia, situs komik Indonesia, Nonton Anime, Nonton Komik, anime sub, anime dub, komik bahasa Indonesia, anime bahasa Indonesia, situs streaming anime Indonesia, situs streaming komik Indonesia, Kissanime, Crunchyroll, Animeindo, Mangaku, Komikid, Komic, Otaku.id, Cinenesia, Kamehameha.id, NontonAnime.id, DuniaKomik, Soranime, KomikKomik" />
  <meta name="format-detection" content="telephone=no" />
  <meta name="apple-mobile-web-app-capable" content="yes" />
  <meta name="apple-mobile-web-app-title" content="<?=$site_TITLE ?>" />
  <meta name="apple-mobile-web-app-status-bar-style" content="default" />
  <meta property="og:title" content="<?=$site_TITLE ?> - Nonton Anime dan Komik Terbaru Setiap Hari" />
  <meta property="og:description" content="Temukan dunia anime dan komik tanpa gangguan di <?=$site_TITLE ?>! Nikmati seri favorit Anda secara gratis, tanpa iklan yang mengganggu pengalaman menonton Anda. Bergabunglah sekarang untuk update anime dan komik terbaru setiap hari di <?=$site_TITLE ?>!" />
  <meta property="og:site_name" content="<?=$site_TITLE ?>" />
  <meta property="og:image" content="<?=$banner?>"/>
  <meta property="og:type" content="website" />
  <meta name="twitter:card" content="summary" />
  <meta name="twitter:title" content="<?=$site_TITLE ?> - Nonton Anime dan Komik Terbaru Setiap Hari" />
  <meta name="twitter:description" content="Temukan dunia anime dan komik tanpa gangguan di <?=$site_TITLE ?>! Nikmati seri favorit Anda secara gratis, tanpa iklan yang mengganggu pengalaman menonton Anda. Bergabunglah sekarang untuk update anime dan komik terbaru setiap hari di <?=$site_TITLE ?>!" />
  <meta name="twitter:image" content="<?=$banner?>"/>
  <link rel="shortcut icon" href="<?=$siteICON ?>" />
  <link rel="apple-touch-icon" href="<?=$siteICON ?>" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy2.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy3.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/cihuy4.css" />
  <script src="https://cdn.tailwindcss.com"></script>
<style>.random-color{animation:5s infinite colorChange}@keyframes colorChange{0%{color:red}25%{color:#0f0}50%{color:#00f}75%{color:#ff0}100%{color:#f0f}}  </style>
</head>

<body>
  <div>
    <?php include('inc/navbar.php'); ?>
    <div class="flex flex-row transition-all duration-300 ease-in-out">
      <div class="w-screen max-w-full overflow-hidden lg:pl-16">
        <!-- Tranding -->
        <div class="relative flex items-center justify-center flex-col">
          <div class="absolute h-[101%] w-full bg-gradient-to-r from-black from-0% to-transparent to-50%"></div>
          <div class="absolute h-[101%] w-full bg-gradient-to-l from-black/60 from-0% to-transparent to-60%"></div>
          <div class="absolute h-[101%] w-full bg-gradient-to-t from-black from-0% to-transparent to-50%"></div>
          <div class="absolute h-[101%] w-full bg-gradient-to-b from-transparent from-0% to-[#05010e] to-100%"></div>
          <span class="h-[50vh] sm:h-[70vh] md:h-[100vh]">
            <img
            alt="Tokidoki Bosotto Russiago de Dereru Tonari no Alya-san"
            fetchpriority="high"
            loading="eager"
            width="200"
            height="200"
            decoding="async"
            data-nimg="1"
            class="w-full h-full object-cover overflow-hidden"
            src="/storage/alya.png"
            style="color: transparent;"
            />
          </span>
          <div class="absolute w-[90%] flex flex-col gap-0.5 md:w-[80%] lg:w-[65%] xl:w-[55%] bottom-[15%] md:bottom-[150px] lg:left-[2.5%] md:left-[40px] sm:left-[30px] left-[3%]">
            <h3 class="text-[0.9rem] sm:text-[1.3rem] font-semibold text-[#ed2672] my-1">#1 Trending</h3>
            <h1 class="text-[1.3rem] font-semibold sm:text-[2.2rem] md:text-[2.7rem] text-ellipsis line-clamp-2">Tokidoki Bosotto Russiago de Dereru Tonari no Alya-san</h1>
            <div class="flex sm:gap-4 sm:text-[0.95rem] sm:my-2 text-[0.8rem] gap-3 mt-1 mb-2 sm:mt-2 font-medium">
              <span class="flex">
                <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 mr-1" viewBox="0 0 48 48">
                  <defs>
                    <mask id="ipSPlay0">
                      <g fill="none" stroke-linejoin="round" stroke-width="4">
                        <path fill="#fff" stroke="#fff" d="M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4S4 12.954 4 24s8.954 20 20 20Z"></path>
                        <path fill="#000" stroke="#000" d="M20 24v-6.928l6 3.464L32 24l-6 3.464l-6 3.464z"></path>
                      </g>
                    </mask>
                  </defs>
                  <path fill="currentColor" d="M0 0h48v48H0z" mask="url(#ipSPlay0)"></path>
                </svg>
                TV
              </span>
              <span class="text-[#2fc867]">Ongoing</span>
              <span class="flex items-center">
                <svg class="w-5 h-5 mr-1 text-gray-800 dark:text-white" aria-hidden="true" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                  <path stroke="currentColor" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M4 10h16M8 14h8m-4-7V4M7 7V4m10 3V4M5 20h14c.6 0 1-.4 1-1V7c0-.6-.4-1-1-1H5a1 1 0 0 0-1 1v12c0 .6.4 1 1 1Z"></path>
                </svg>
                Jul 3, 2024
              </span>
              <span class="flex items-center">
                <svg viewBox="0 0 32 32" class="w-5 h-5 mr-1" fill="none" aria-hidden="true" focusable="false" xmlns="http://www.w3.org/2000/svg">
                  <path
                    fill-rule="evenodd"
                    clip-rule="evenodd"
                    d="M4.6661 6.66699C4.29791 6.66699 3.99943 6.96547 3.99943 7.33366V24.667C3.99943 25.0352 4.29791 25.3337 4.6661 25.3337H27.3328C27.701 25.3337 27.9994 25.0352 27.9994 24.667V7.33366C27.9994 6.96547 27.701 6.66699 27.3328 6.66699H4.6661ZM8.66667 21.3333C8.29848 21.3333 8 21.0349 8 20.6667V11.3333C8 10.9651 8.29848 10.6667 8.66667 10.6667H14C14.3682 10.6667 14.6667 10.9651 14.6667 11.3333V12.6667C14.6667 13.0349 14.3682 13.3333 14 13.3333H10.8C10.7264 13.3333 10.6667 13.393 10.6667 13.4667V18.5333C10.6667 18.607 10.7264 18.6667 10.8 18.6667H14C14.3682 18.6667 14.6667 18.9651 14.6667 19.3333V20.6667C14.6667 21.0349 14.3682 21.3333 14 21.3333H8.66667ZM18 21.3333C17.6318 21.3333 17.3333 21.0349 17.3333 20.6667V11.3333C17.3333 10.9651 17.6318 10.6667 18 10.6667H23.3333C23.7015 10.6667 24 10.9651 24 11.3333V12.6667C24 13.0349 23.7015 13.3333 23.3333 13.3333H20.1333C20.0597 13.3333 20 13.393 20 13.4667V18.5333C20 18.607 20.0597 18.6667 20.1333 18.6667H23.3333C23.7015 18.6667 24 18.9651 24 19.3333V20.6667C24 21.0349 23.7015 21.3333 23.3333 21.3333H18Z"
                    fill="currentColor"
                    ></path>
                </svg>
                12
              </span>
            </div>
            <div class="hidden sm:!block">
              <p class="line-clamp-2 md:line-clamp-3 text-ellipsis text-[#d6d6d6] mb-5">
                Cerdas, halus, dan luar biasa cantik, Alisa Mikhailovna Kujou yang setengah Rusia dan Jepang dianggap sebagai idola sekolahnya. Dengan rambut perak panjangnya, mata birunya yang memesona, dan kulitnya yang sangat putih, dia telah memikat hati banyak siswa laki-laki sekaligus sangat dikagumi oleh semua siswa lainnya. Meski begitu, karena kepribadiannya yang tampaknya tidak bisa didekati, semua orang tetap waspada terhadap gadis yang hampir sempurna itu.Salah satu dari sedikit pengecualian adalah teman sekelas Alisa, Masachika Kuze, seorang anak laki-laki yang relatif biasa-biasa saja yang menghabiskan hari-harinya menonton anime dan bermain game gacha. Meskipun sikapnya acuh tak acuh, Masachika adalah satu-satunya siswa yang menerima perhatian Alisa. Tidak bisa jujur sepenuhnya, Alisa sering bersikap kasar pada Masachika dan hanya mengungkapkan rasa sayangnya dalam bahasa Rusia. Namun, tanpa sepengetahuannya, Masachika sebenarnya memahami bahasa tersebut namun hanya berpura-pura sebaliknya demi kesenangannya sendiri.Saat pasangan aneh ini terus bertukar komentar yang jenaka dan lucu, hubungan mereka perlahan-lahan menjadi lebih romantis dan menyenangkan—dan Alisa mungkin akhirnya belajar untuk dengan bebas menyampaikan perasaannya yang sebenarnya.
              </p>
            </div>
            <div class="w-fit">
              <a href="/anime/tokidoki-bosotto-russia-go-de-dereru-tonari-no-alya-san/">
                <button class="px-4 py-2 bg-[#4d148c] rounded-full text-sm font-medium flex items-center">
                  <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 mr-1" viewBox="0 0 48 48">
                    <defs>
                      <mask id="ipSPlay0">
                        <g fill="none" stroke-linejoin="round" stroke-width="4">
                          <path fill="#fff" stroke="#fff" d="M24 44c11.046 0 20-8.954 20-20S35.046 4 24 4S4 12.954 4 24s8.954 20 20 20Z"></path>
                          <path fill="#000" stroke="#000" d="M20 24v-6.928l6 3.464L32 24l-6 3.464l-6 3.464z"></path>
                        </g>
                      </mask>
                    </defs>
                    <path fill="currentColor" d="M0 0h48v48H0z" mask="url(#ipSPlay0)"></path>
                  </svg>
                  Play Now
                </button>
              </a>
            </div>
          </div>
        </div>
        <!-- end Tranding -->
        <?php include('inc/lanjut.html'); ?>
        <div class="sm:max-w-[97%] md:max-w-[95%] xl:max-w-[95%] mx-auto flex flex-col md:gap-11 sm:gap-7 gap-5 md:mt-3">
          <div>
            <div style="cursor: auto;"></div>
          </div>
          <div></div>
          <div>
            <?php if ($animeData['status'] && $komikData['status']) : ?>
            <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
              <div class="flex items-center gap-2 px-3 xl:px-0">
                <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Anime update</h1>
              </div>
              <div class="relative">
                <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m15 18-6-6 6-6"></path>
                  </svg>
                </span>
                <span class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m9 18 6-6-6-6"></path>
                  </svg>
                </span>
                <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0" id="Popular This Season" style="cursor: auto;">
                  <?php foreach ($animeData['data']['results'] as $anime) :
                  $linkanime = strpos($anime['link'], '/anime/') !== false ? $anime['link'] : '/episode/' . ltrim($anime['link'], '/');
                  ?>
                  <a href="<?=$linkanime ?>" style="cursor: pointer;">
                    <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                      <?php if (!empty($anime['episode'])): ?>
                      <div class="flex-shrink-0 absolute top-0 right-0 flex font-medium items-center justify-center gap-[.4rem] bg-black/60 backdrop-blur text-white !text-xs line-clamp-1 z-[7] px-2 py-1 rounded-bl-lg tracking-wider">
                        <span class="hidden md:flex">Episode</span>
                        <span class="md:hidden">Ep</span>
                        <span class="font-medium text-purple-400"><?= htmlspecialchars($anime['episode'], ENT_QUOTES, 'UTF-8') ?></span>
                      </div>
                      <?php endif; ?>
                      <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                        <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                          <img
                          alt="<?= $anime['judul'] ?>"
                          loading="eager"
                          width="155"
                          height="230"
                          decoding="async"
                          data-nimg="1"
                          class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105"
                          style="color: transparent;"
                          src="<?=$imgk?><?= $anime['gambar'] ?>"
                          />
                        </div>
                        <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                          <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                            <?php if (!empty($anime['episode'])): ?>
                            <span class="uppercase">Ep <?= htmlspecialchars($anime['episode'], ENT_QUOTES, 'UTF-8') ?></span> <span class="text-[10px]">•</span>
                            <?php endif; ?>
                            <span class="font-semibold text-green-400"><?= $anime['jenis'] ?></span>
                          </div>
                        </div>
                      </div>
                      <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2">
                        <span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full bg-green-500 xl:hidden"></span> <?= $anime['judul'] ?>
                      </span>
                    </div>
                  </a>
                  <?php endforeach; ?>

                </div>
              </div>
            </div>
            <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
              <div class="flex items-center gap-2 px-3 xl:px-0">
                <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Komik Romance</h1>
              </div>
              <div class="relative">
                <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m15 18-6-6 6-6"></path>
                  </svg>
                </span>
                <span class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m9 18 6-6-6-6"></path>
                  </svg>
                </span>
                <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0" id="Most Favorite" style="cursor: auto;">
                  <?php
                  $randomFile = 'cache/romance' . rand(1, 5) . '.json';
                  $data = json_decode(file_get_contents($randomFile), true);
                  $results = $data['data']['results'];
                  foreach ($results as $result): ?>
                  <a href="<?= $result['link'] ?>" style="cursor: pointer;">
                    <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                      <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                        <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                          <img
                          alt="<?= $result['judul'] ?>"
                          loading="eager"
                          width="155"
                          height="230"
                          decoding="async"
                          data-nimg="1"
                          class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105"
                          style="color: transparent;"
                          src="<?=$imgk?><?= $result['gambar'] ?>"
                          />
                        </div>
                        <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                          <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                            <?php if (!empty($result['jenis'])): ?>
                            <span class="uppercase"><?= $result['jenis'] ?></span>
                            <span class="text-[10px]">•</span>
                            <?php endif; ?>
                            <?php if (!empty($result['warna'])): ?>
                            <span class="font-semibold text-white random-color"><?= $result['warna'] ?></span>
                            <span class="text-[10px]">•</span>
                            <?php endif; ?>
                            <?php if (!empty($result['nilai'])): ?>
                            <span class="">
                              <?= $result['nilai'] ?>
                            </span>
                            <?php endif; ?>
                          </div>
                        </div>
                      </div>
                      <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2">
                        <span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full hidden xl:hidden"></span><?= $result['judul'] ?>
                      </span>
                    </div>
                  </a>
                  <?php endforeach; ?>
                </div>
              </div>
            </div>
            <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
              <div class="flex items-center gap-2 px-3 xl:px-0">
                <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Sekai anime</h1>
              </div>
              <div class="relative">
                <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m15 18-6-6 6-6"></path>
                  </svg>
                </span>
                <span class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
                  <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                    <path d="m9 18 6-6-6-6"></path>
                  </svg>
                </span>
                <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0" id="Most Favorite" style="cursor: auto;">
                  <?php
                  $randomFile = 'cache/anisekai' . rand(1, 4) . '.json';
                  $data = json_decode(file_get_contents($randomFile), true);
                  $result = $data['data']['result'];
                  foreach ($result as $result): ?>
                  <a href="<?= $result['link'] ?>" style="cursor: pointer;">
                    <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                      <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                        <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                          <img
                          alt="<?= $result['judul'] ?>"
                          loading="eager"
                          width="155"
                          height="230"
                          decoding="async"
                          data-nimg="1"
                          class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105"
                          style="color: transparent;"
                          src="<?=$imgk?><?= $result['gambar'] ?>"
                          />
                        </div>
                        <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                          <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                            <?php if (!empty($result['episode'])): ?>
                            <span class="uppercase"><?= $result['episode'] ?></span>
                            <span class="text-[10px]">•</span>
                            <?php endif; ?>
                            <?php if (!empty($result['jenis'])): ?>
                            <span class="font-semibold text-white random-color"><?= $result['jenis'] ?></span>
                            <?php endif; ?>
                          </div>
                        </div>
                      </div>
                      <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2">
                        <span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full hidden xl:hidden"></span><?= $result['judul'] ?>
                      </span>
                    </div>
                  </a>
                  <?php endforeach; ?>
                </div>
              </div>
            </div>
          </div>

          <div class="lg:flex lg:flex-row justify-between lg:gap-20">
            <div class="VerticalList_verticalcard__EZzzO" style="display: flex;">
              <div class="items-center gap-2 px-3 xl:px-0 hidden lg:flex">
                <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Chapter Update</h1>
              </div>
              <div class="VerticalList_mobiletop__nLEOa">
                <div class="flex flex-row gap-[8px] items-center">
                  <span class="VerticalList_bar___qiZ9"></span>
                  <h1 class="VerticalList_mobiletitle__AI0p7">Chapter Update</h1>
                </div>
              </div>
              <?php foreach ($komikData['data']['latestkomik'] as $komik) : ?>
              <div class="VerticalList_vcarditem__aVQGc group">
                <div class="VerticalList_vcardcontent__Au1Vj">
                  <div class="VerticalList_vcardleft__z5Rbh">
                    <a href="<?= $komik['link'] ?>">
                      <img
                      alt="image"
                      loading="lazy"
                      width="60"
                      height="90"
                      decoding="async"
                      data-nimg="1"
                      class="VerticalList_vcardimg__jqFbU"
                      style="color: transparent;"
                      src="<?=$imgk?><?= $komik['gambar'] ?>"
                      />
                    </a>
                    <div class="VerticalList_vcardinfo__9BVa5">
                      <div class="VerticalList_linktitle__8dEuc">
                        <a href="<?= $komik['link'] ?>"><?= $komik['Title'] ?></a>
                      </div>
                      <div class="VerticalList_vcardleftb__5Y_HC">
                        <span class="VerticalList_season__FDIRU"><?= $komik['type'] ?></span>
                        <?php if (!empty($komik['warna'])): ?>
                        <span class="VerticalList_dot__KHDZL">.</span>
                        <span class="VerticalList_vstatus__jnB_t random-color"><?= str_replace('Warna', 'Color', $komik['warna']) ?>
                        </span>
                        <?php endif; ?>
                      </div>
                    </div>
                  </div>
                  <div class="VerticalList_vcardright__D2BAk">
                    <div class="VerticalList_vpopular__n4w5W">
                      <span class="VerticalList_format__bHV3L"><a href="/chapter<?= $komik['chapter']['link'] ?>" class="text-purple-600"><?= $komik['chapter']['Title'] ?></a></span>
                      <div>
                        <span class="VerticalList_bpopular__AehQU"><?= $komik['chapter']['Date'] ?></span>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
              <?php endforeach; ?>
              <div>
                <div class="flex flex-col gap-1 xl:max-w-[80%]"></div>
              </div>
              <div>
                <?php else : ?>
                <p>
                  Data tidak tersedia.
                </p>
                <?php endif; ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
    
    <div class="items-center" style="border: 3px solid #7e22ce; border-radius: 10px; padding: 10px; width: fit-content; text-align: center;">
    <embed src="https://www.chatbro.com/en/68z77/" width="300" height="400" style="border: none;">
</div>
    <!-- footer -->
    <?php include('inc/footer.php'); ?>
  </div>
  <section class="gototop"></section>
</body>
</html>