<?php
$request_uri = $_SERVER['REQUEST_URI'];
$page = explode('/', $request_uri);
$komik_info = isset($page[2]) ? rtrim($page[2], '/') : '';

// File cache
$cacheDuration = 3600; // 1 hour
$cacheDir = 'cache/komik/';
$cacheFile = $cacheDir . md5($komik_info) . '.json'; // Cache file name based on endpoint hash

// Function to fetch data from API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Function to get data from cache or API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();

  // Check if cache file exists and is still valid
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Fetch data from API and save to cache
  $data = fetchData($apiUrl);
  if (isset($data['status']) && $data['status'] === true) {
    // Ensure cache directory exists
    if (!file_exists(dirname($cacheFile))) {
      mkdir(dirname($cacheFile), 0755, true);
    }
    file_put_contents($cacheFile, json_encode($data));
  }

  return $data;
}

// Define the API URL for the endpoint
$apiUrl = "$api/api/komik/manga/$komik_info";

// Fetch data with caching
$data = getData($cacheFile, $apiUrl, $cacheDuration);
// Ganti \n dan spasi berlebih dengan spasi tunggal
$judul = isset($data['judul']) ? preg_replace('/\s+/', ' ', $data['judul']) : 'N/A';
$sinopsis = isset($data['sinopsis']) ? preg_replace('/\s+/', ' ', $data['sinopsis']) : 'N/A';
?>
<html lang="en" class="dark text-foreground bg-background">

<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="theme-color" content="#05010d">
  <title><?php echo htmlspecialchars($judul); ?> | <?=$site_TITLE ?> - Baca Komik Indonesia</title>

  <meta name="description" content="<?php echo htmlspecialchars(substr($sinopsis, 0, 150)); ?> - Baca komik terbaru dan populer hanya di <?=$site_TITLE ?>">
  <link rel="canonical" href="<?=$siteURL ?>/komik/<?=$komik_info ?>" />
  <meta name="application-name" content="<?=$site_TITLE ?>">
  <meta name="keywords" content="Baca komik, Manga Indonesia, Komik terbaru, Komik online, Komik populer, <?php echo htmlspecialchars($judul); ?>, baca komik kiryuu.cc, komikindo, mangaku, bacamanga, komikcast, mangakita, komiku, komikstation, mangadop, westmanga, otakudesu, komikid, komikindo.web.id, manganime, mangacanblog, samehadaku, mangatoon, bacamanga.cc, komikidn, mangakita.net, komikstation.com, <?=$site_TITLE ?>, baca manga, baca komik online terbaik">

  <meta name="format-detection" content="telephone=no">
  <meta name="apple-mobile-web-app-capable" content="yes">
  <meta name="apple-mobile-web-app-title" content="<?=$site_TITLE ?> - Baca Komik Online">
  <meta name="apple-mobile-web-app-status-bar-style" content="default">

  <meta property="og:title" content="<?php echo htmlspecialchars($judul); ?> | <?=$site_TITLE ?> - Baca Komik Indonesia">
  <meta property="og:description" content="<?php echo htmlspecialchars(substr($sinopsis, 0, 150)); ?> - Temukan komik terbaru dan populer di <?=$site_TITLE ?>">
  <meta property="og:image" content="<?php echo htmlspecialchars($data['thumbnail'] ?? 'N/A'); ?>">
  <meta property="og:url" content="<?=$siteURL ?>/komik/<?=$komik_info?>">

  <meta name="twitter:card" content="summary_large_image">
  <meta name="twitter:title" content="<?php echo htmlspecialchars($judul); ?> - Baca Komik Indonesia">
  <meta name="twitter:description" content="<?php echo htmlspecialchars(substr($sinopsis, 0, 150)); ?> - Temukan komik terbaru dan populer di <?=$site_TITLE ?>">
  <meta name="twitter:image" content="<?php echo htmlspecialchars($data['thumbnail'] ?? 'N/A'); ?>">

  <link rel="manifest" href="/manifest.json" crossorigin="use-credentials">
  <link rel="shortcut icon" href="/favicon-16x16.png">
  <link rel="apple-touch-icon" href="/apple-touch-icon.png">
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/dbf317c5a42383e0.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/334dd403868c5153.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/1ccc80749f9874d3.css" />
  <link rel="stylesheet" href="<?=$siteURL ?>/assets/css/a5eef6a901953dd4.css" />
  <script src="https://cdn.tailwindcss.com"></script>
</head>


<body class="__className_7df6af">
  <div>
    <?php include('inc/navbar.php'); ?>
    <div class="w-screen max-w-full overflow-hidden lg:pl-9">
      <div class="h-[500px] ">
        <div class="AnimeDetailsTop_detailsbanner__O2s9w">
          <div class="AnimeDetailsTop_detailsbgimage__QHMrr" style="background-image:url(/proxy.php?img=<?php echo htmlspecialchars($data['thumbnail'] ?? 'N/A'); ?>);background-position:center;background-size:cover;height:100%"></div>
          <div class="AnimeDetailsTop_gradientOverlay__g3uf8"></div>
          <div class="lg:block hidden absolute h-[101%] w-full bg-gradient-to-r from-[#05010e] left-4 from-0% to-transparent to-40%"></div>
          <div class="absolute h-[101%] w-full bg-gradient-to-b from-black/70 from-0% to-transparent to-30%"></div>
          <div class="AnimeDetailsTop_detailsinfo__CBeLz">
            <div class="AnimeDetailsTop_detailsimgcon__6vDUf">
              <img alt="Image" loading="lazy" width="200" height="200" decoding="async" data-nimg="1" class="AnimeDetailsTop_detailsimage__JoMvk" style="color:transparent" src="/proxy.php?img=<?php echo htmlspecialchars($data['thumbnail'] ?? 'N/A'); ?>" alt="<?php echo htmlspecialchars($data['judul'] ?? 'N/A'); ?>">
            </div>
            <div
              class="AnimeDetailsTop_detailstitle___n4ki">
              <h1 class="AnimeDetailsTop_title__THumD text-[1.7rem] lg:text-[1.9rem] font-semibold"><?php echo str_replace('Komik', '', htmlspecialchars($data['judul'] ?? 'N/A')); ?></h1>
              <h4 class="AnimeDetailsTop_alttitle__6qsft !font-medium"><?php echo htmlspecialchars($data['informasi']['Judul Alternatif'] ?? 'N/A'); ?></h4>
              <p class="AnimeDetailsTop_scores__aDYg4 ">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-[17px] h-[17px] mr-[2px]">
                  <path stroke-linecap="round" stroke-linejoin="round" d="M11.48 3.499a.562.562 0 011.04 0l2.125 5.111a.563.563 0 00.475.345l5.518.442c.499.04.701.663.321.988l-4.204 3.602a.563.563 0 00-.182.557l1.285 5.385a.562.562 0 01-.84.61l-4.725-2.885a.563.563 0 00-.586 0L6.982 20.54a.562.562 0 01-.84-.61l1.285-5.386a.562.562 0 00-.182-.557l-4.204-3.602a.563.563 0 01.321-.988l5.518-.442a.563.563 0 00.475-.345L11.48 3.5z"></path>
                </svg><?php echo htmlspecialchars($data['rating'] ?? 'N/A'); ?> | <span class="AnimeDetailsTop_activestatus__4_CXd font-medium"><?php echo htmlspecialchars(str_replace(['Berjalan', 'Tamat'], ['Ongoing', 'completed'], $data['informasi']['Status'] ?? 'N/A')); ?></span>
              </p>
              <div class="flex items-center">
                <a class="AnimeDetailsTop_detailswatch__4hz40 false hover:opacity-80 transition-all " href="/chapter<?php echo htmlspecialchars($data['chapterPertama']['link'] ?? '#'); ?>">
                  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" aria-hidden="true" class="w-5 h-5 mr-1">
                    <path fill-rule="evenodd" d="M4.5 5.653c0-1.426 1.529-2.33 2.779-1.643l11.54 6.348c1.295.712 1.295 2.573 0 3.285L7.28 19.991c-1.25.687-2.779-.217-2.779-1.643V5.653z" clip-rule="evenodd"></path>
                  </svg><?php echo htmlspecialchars($data['chapterPertama']['teks'] ?? 'N/A'); ?></a>
                <button class="AnimeDetailsTop_detailsaddlist__mXF4V hover:opacity-80 transition-all">Add to List</button>
              </div>
            </div>
          </div>
          <div class="
            fixed inset-0 flex justify-center items-center z-50 h-screen w-screen
            invisible
            ">
            <div class="
              bg-[#17171c] shadow-md shadow-black/70 rounded-xl transition-all py-3
              scale-75 opacity-0
              ">
              <button class="absolute top-2 right-2 p-1 rounded-lg text-gray-400 bg-content1 hover:text-white">
                <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 15 15">
                  <path fill="currentColor" d="M3.64 2.27L7.5 6.13l3.84-3.84A.92.92 0 0 1 12 2a1 1 0 0 1 1 1a.9.9 0 0 1-.27.66L8.84 7.5l3.89 3.89A.9.9 0 0 1 13 12a1 1 0 0 1-1 1a.92.92 0 0 1-.69-.27L7.5 8.87l-3.85 3.85A.92.92 0 0 1 3 13a1 1 0 0 1-1-1a.9.9 0 0 1 .27-.66L6.16 7.5L2.27 3.61A.9.9 0 0 1 2 3a1 1 0 0 1 1-1c.24.003.47.1.64.27"></path>
                </svg>
              </button>
              <div class="px-5 pt-4 pb-2">
                <div class="max-w-[90%] hidden md:flex">
                  <h3 class="text-2xl font-semibold text-textp line-clamp-1">Tokidoki Bosotto Russiago de Dereru Tonari no Alya-san</h3>
                </div>
                <div class="w-[650px] h-[350px] my-2"></div>
              </div>
            </div>
          </div>
        </div>
      </div>
      <div class="AnimeDetailsBottom_detailstabs__hVi_H">
        <div class="AnimeDetailsBottom_tabHeader__HFVgw">
          <div class="AnimeDetailsBottom_tabItem__00i_M AnimeDetailsBottom_selected__yKotU">
            Overview
            <div class="AnimeDetailsBottom_indicator__03rn1"></div>
          </div>
        </div>
        <div>
          <div class="AnimeDetailsBottom_detailscard__cDaTT">
            <div class="AnimeDetailsBottom_card1__CS2TA">
              <h3 class="AnimeDetailsBottom_detailsheading__GaG5c">Detail</h3>
              <div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r font-semibold !text-[15px]">Status</span><span class="AnimeDetailsBottom_con__uOKud !text-white cursor-pointer font-semibold"><?php echo htmlspecialchars(str_replace(['Berjalan', 'Tamat'], ['Ongoing', 'completed'], $data['informasi']['Status'] ?? 'N/A')); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Type</span> <span class="AnimeDetailsBottom_con__uOKud"><?php echo htmlspecialchars($data['informasi']['Jenis Komik'] ?? 'N/A'); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Rilis</span> <span class="AnimeDetailsBottom_con__uOKud "><?php echo htmlspecialchars($data['informasi']['Rilis'] ?? 'N/A'); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Author</span> <span class="AnimeDetailsBottom_con__uOKud"><?php echo htmlspecialchars($data['informasi']['Author'] ?? 'N/A'); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Artis</span> <span class="AnimeDetailsBottom_con__uOKud"><?php echo htmlspecialchars($data['informasi']['Artis'] ?? 'N/A'); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Serialisasi</span> <span class="AnimeDetailsBottom_con__uOKud "><?php echo htmlspecialchars($data['informasi']['Serialisasi'] ?? 'N/A'); ?></span>
                </div>
                <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                  <span class="AnimeDetailsBottom_sideheading__aPw8r">Genre</span>
                  <?php if (!empty($data['genre'])): ?>
                  <?php foreach ($data['genre'] as $genre): ?>
                  <span class="AnimeDetailsBottom_con__uOKud"><a href="<?php echo htmlspecialchars($genre['link'] ?? '#'); ?>"><?php echo htmlspecialchars($genre['judul'] ?? 'N/A'); ?>,</a></span>
                  <?php endforeach; ?>
                  <?php else : ?>
                  <p>
                    N/A
                    <?php endif; ?>
                  </div>
                  <div class="AnimeDetailsBottom_singlecontent__bW8T7">
                    <span class="AnimeDetailsBottom_sideheading__aPw8r">Kredit</span> <span class="AnimeDetailsBottom_con__uOKud"><a href="https://komikcast.cafe/komik/<?=$komik_info ?>">komikcast.cafe</a></span>
                  </div>
                </div>
              </div>
              <div class="AnimeDetailsBottom_card2__m40_q">
                <div class="flex justify-between items-center mb-1.5">
                  <h3 class="AnimeDetailsBottom_detailsheading__GaG5c font-semibold m-0">Description</h3>
                  <div class="flex gap-3 items-center md:hidden">
                    <a href="/chapter<?php echo htmlspecialchars($data['chapterPertama']['link'] ?? '#'); ?>" class="text-sm bg-white text-black px-2 rounded-lg h-min py-1 opacity-95 font-medium"><?php echo htmlspecialchars($data['chapterPertama']['teks'] ?? 'N/A'); ?></a>
                    <a href="/chapter<?php echo htmlspecialchars($data['chapterTerakhir']['link'] ?? '#'); ?>" class="text-sm bg-white text-black px-2 rounded-lg h-min py-1 opacity-95 font-medium"><?php echo htmlspecialchars($data['chapterTerakhir']['teks'] ?? 'N/A'); ?></a>
                  </div>
                </div>
                <div class="AnimeDetailsBottom_descriptioncontent__v_ijv tracking-normal">
                  <p>
                    <?php echo nl2br(htmlspecialchars($data['sinopsis'] ?? 'N/A')); ?>
                  </p>
                </div>
                <div class="AnimeDetailsBottom_descriptioncontentmobile__DLX6k">
                  <p>
                    <?php echo nl2br(htmlspecialchars($data['sinopsis'] ?? 'N/A')); ?>
                  </p>
                </div>
              </div>
              <div class="
                fixed inset-0 flex justify-center items-center z-50 h-screen w-screen
                invisible
                ">
                <div class="
                  bg-[#17171c] shadow-md shadow-black/70 rounded-xl transition-all py-3
                  scale-75 opacity-0
                  ">
                  <button class="absolute top-2 right-2 p-1 rounded-lg text-gray-400 bg-content1 hover:text-white">
                    <svg xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 15 15">
                      <path fill="currentColor" d="M3.64 2.27L7.5 6.13l3.84-3.84A.92.92 0 0 1 12 2a1 1 0 0 1 1 1a.9.9 0 0 1-.27.66L8.84 7.5l3.89 3.89A.9.9 0 0 1 13 12a1 1 0 0 1-1 1a.92.92 0 0 1-.69-.27L7.5 8.87l-3.85 3.85A.92.92 0 0 1 3 13a1 1 0 0 1-1-1a.9.9 0 0 1 .27-.66L6.16 7.5L2.27 3.61A.9.9 0 0 1 2 3a1 1 0 0 1 1-1c.24.003.47.1.64.27"></path>
                    </svg>
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
        <div class="Episodesection_episodesection__Pz__g">
          <div class="Episodesection_eptopsection__S00Yy">
            <div class="Episodesection_epleft__ReCcn">
              <div class="flex items-center gap-2">
                <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
                <h1 class="text-[19px] sm:text-[22px] font-medium md:font-semibold">Chapter</h1>
              </div>
            </div>
            <div class="Episodesection_epright__6UDxQ">
              <div class="Episodesection_selects__qJVPp">
                <div class="flex w-[75px] flex-col gap-2 mr-2">
                  <div data-slot="base" data-filled="true" data-has-value="true" class="group flex flex-col w-full transition-background motion-reduce:transition-none !duration-150 group relative justify-end data-[has-label=true]:mt-[calc(theme(fontSize.small)_+_10px)] !m-0 !p-0">

                  </div>
                </div>
              </div>

            </div>
          </div>
          <div>
            <div class="Epimglist_epimgcondiv__UVpLl">
              <?php if (!empty($data['chapters'])): ?>
              <?php foreach ($data['chapters'] as $chapter): ?>
              <a class="flex flex-row items-center transition-all duration-300 ease-out hover:scale-[0.98] hover:bg-[#27272c] rounded-lg xl:rounded-2xl my-[6px] bg-[#18181b]  " href="/chapter<?php echo htmlspecialchars($chapter['link'] ?? '#'); ?>">
                <div class="Epimglist_epcondiv__f_l4B rounded-lg xl:rounded-2xl">
                  <img alt="CH <?php echo str_replace('Chapter', '', htmlspecialchars($chapter['judul'] ?? '')); ?>" loading="lazy" width="200" height="200" decoding="async" data-nimg="1" class="Epimglist_epimgcon__Uj_1I rounded-lg xl:rounded-2xl" src="/proxy.php?img=<?php echo htmlspecialchars($data['thumbnail'] ?? 'N/A'); ?>" alt="<?php echo htmlspecialchars($data['judul'] ?? 'N/A'); ?>"
                  style="color: transparent;"><span class="Epimglist_epimgnumber__D_H8G font-semibold">CH <?php echo str_replace('Chapter', '', htmlspecialchars($chapter['judul'] ?? '')); ?></span>
                  <div class="absolute bottom-0 left-0 w-full rounded-lg z-10">
                    <hr class="border-red-600 !border-[.10rem] rounded-lg xl:rounded-2xl" style="width: 0%;">
                  </div>
                </div>
                <div class="Epimglist_epimgright__CBLYG">
                  <div class="Epimglist_epimgtitle__iuJmy font-medium">
                    <span class=""></span><?php echo str_replace('Komik', '', htmlspecialchars($data['judul'] ?? 'N/A')); ?>
                  </div>
                  <div class="Epimglist_epimgdescription__jMNPY font-normal tracking-wide">
                    <?php echo htmlspecialchars($chapter['tanggal'] ?? 'N/A'); ?>
                  </div>
                  <div class="flex flex-row gap-6"></div>
                </div>
              </a>
              <?php endforeach; ?>
              <?php else : ?>
              <a class="flex flex-row items-center transition-all duration-300 ease-out hover:scale-[0.98] hover:bg-[#27272c] rounded-lg xl:rounded-2xl my-[6px] bg-[#18181b]  " href="#">
                <div class="Epimglist_epcondiv__f_l4B rounded-lg xl:rounded-2xl">
                  <img alt="Alya Hides Her Feelings in Russian" loading="lazy" width="200" height="200" decoding="async" data-nimg="1" class="Epimglist_epimgcon__Uj_1I rounded-lg xl:rounded-2xl" src="/proxy.php?img=<?=$notfun ?>"
                  style="color: transparent;">
                  <div class="absolute bottom-0 left-0 w-full rounded-lg z-10">
                    <hr class="border-red-600 !border-[.10rem] rounded-lg xl:rounded-2xl" style="width: 0%;">
                  </div>
                </div>
                <div class="Epimglist_epimgright__CBLYG">
                  <div class="Epimglist_epimgtitle__iuJmy font-medium">
                    <span class="">Not available</span>
                  </div>
                  <div class="Epimglist_epimgdescription__jMNPY font-normal tracking-wide">
                    traktir bang
                  </div>
                  <div class="flex flex-row gap-6"></div>
                </div>
              </a>
              <?php endif; ?>

            </div>
          </div>
        </div>

        <div class="recommendationglobal">
          <div class="scroll-smooth flex flex-col mx-auto my-1 md:my-0">
            <div class="flex items-center gap-2 px-3 xl:px-0">
              <span class="w-[0.35rem] h-6 md:w-[0.3rem] rounded-md bg-white"></span>
              <h1 class="text-[19px] sm:text-[22px] my-4 font-medium md:font-semibold">Rekomen</h1>
            </div>
            <div class="relative">
              <span class="flex items-center mb-5 cursor-pointer absolute left-0 bg-gradient-to-r from-black z-10 transition-all duration-300 invisible opacity-0 h-full "><svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4"><path d="m15 18-6-6 6-6"></path></svg></span>
              <span
                class="flex items-center mb-5 cursor-pointer absolute right-0 bg-gradient-to-l from-black z-10 transition-all duration-300 lg:px-3 visible h-full">
                <svg xmlns="http://www.w3.org/2000/svg" width="28" height="28" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="mb-4">
                  <path d="m9 18 6-6-6-6"></path>
                </svg>
              </span>
              <div class="relative flex flex-nowrap overflow-scroll overflow-y-hidden gap-3 scrollbar-hide pl-[0.75rem] xl:pl-0"style="cursor: auto;">
                <?php foreach ($data['mangaTerkait'] as $manga): ?>
                <a href="<?= htmlspecialchars($manga['link']); ?>" style="cursor: pointer;">
                  <div class="relative flex flex-col h-full hover:cursor-pointer group w-[105px] sm:w-[135px] md:w-[155px] xl:w-[175px]">
                    <div class="relative h-[160px] w-[105px] sm:w-[135px] sm:h-[190px] md:h-[230px] md:w-[155px] xl:h-[255px] xl:w-[175px] rounded-xl xl:rounded-2xl">
                      <div class="w-full h-full rounded-xl xl:rounded-2xl overflow-hidden bg-[#1e1e24] aspect-[15/9] flex-shrink-0 shadow-[4px_0px_5px_0px_rgba(0,0,0,0.3)] group">
                        <img alt="Horimiya" loading="eager" width="155" height="230" decoding="async" data-nimg="1" class="w-full h-full object-cover rounded-xl xl:rounded-2xl transition-transform duration-300 group-hover:scale-105" style="color:transparent" src="/proxy.php?img=<?= htmlspecialchars($manga['gambar']); ?>">
                      </div>
                      <div class="w-full h-full rounded absolute group-hover:bg-gradient-to-t from-black/85 to-transparent opacity-0 group-hover:opacity-100 top-0 z-[5] transition-all duration-300 ease justify-center">
                        <div class="bottom-4 left-0 right-0 absolute text-xs font-medium flex flex-wrap items-center justify-center gap-[.3rem] z-[7]">
                          <span class="font-semibold text-white"><?= htmlspecialchars($manga['info']); ?></span>
                        </div>
                      </div>
                    </div>
                    <span class="overflow-hidden text-center text-[#d1d7e0] pt-1.5 px-1.5 sm:px-2 text-xs sm:text-sm font-medium line-clamp-2"><span class="aspect-square w-2 h-2 inline-block mr-1 rounded-full hidden xl:hidden"></span><?= htmlspecialchars($manga['judul']); ?></span>
                  </div>
                </a>
                <?php endforeach;?>
              </div>
            </div>
          </div>
        </div>

      </div>
      <?php include('inc/footer.php'); ?>
    </div>

  </body>
</html>