<?php
$request_uri = $_SERVER['REQUEST_URI'];
$page = explode('/', $request_uri);
$komik_ch = isset($page[2]) ? rtrim($page[2], '/') : '';

// File cache
$cacheDuration = 3600; // 1 jam
$cacheFile = 'cache/chapter/' . md5($komik_ch) . '.json'; // Nama file cache berdasarkan hash endpoint

// Fungsi untuk mengambil data dari API
function fetchData($url) {
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $url);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
  $response = curl_exec($ch);
  curl_close($ch);
  return json_decode($response, true);
}

// Fungsi untuk mendapatkan data dari cache atau API
function getData($cacheFile, $apiUrl, $cacheDuration) {
  $now = time();

  // Jika file cache ada dan masih berlaku
  if (file_exists($cacheFile) && ($now - filemtime($cacheFile) < $cacheDuration)) {
    return json_decode(file_get_contents($cacheFile), true);
  }

  // Ambil data dari API dan simpan ke cache
  $data = fetchData($apiUrl);
  if (isset($data['status']) && $data['status'] === true) {
    file_put_contents($cacheFile, json_encode($data));
  }

  return $data;
}

// Tentukan URL API untuk endpoint
$apiUrl = "https://your-api-url/api/komik/chapter/$komik_ch";

// Ambil data dengan caching
$data = getData($cacheFile, $apiUrl, $cacheDuration);

// Tampilkan halaman HTML
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title><?=$data['data']['title'] ?? 'N/A'; ?></title>
</head>
<body>
  <h1><?=$data['data']['title'] ?? 'N/A'; ?></h1>
  <p><?=$data['data']['shortDescription'] ?? 'N/A'; ?></p>
  <img src="<?=$data['data']['thumbnail'] ?? 'https://via.placeholder.com/200x285?text=N/A'; ?>" alt="Thumbnail">

  <h2>Images</h2>
  <?php if (!empty($data['data']['images'])): ?>
    <?php foreach ($data['data']['images'] as $image): ?>
      <img src="<?=$image; ?>" alt="Page Image" style="width: 100%;">
    <?php endforeach; ?>
  <?php else: ?>
    <p>No images available</p>
  <?php endif; ?>

  <h2>Chapters</h2>
  <ul>
    <?php if (!empty($data['data']['chapterList'])): ?>
      <?php foreach ($data['data']['chapterList'] as $chapter): ?>
        <li><a href="<?=$chapter['chapterLink']; ?>"><?=$chapter['chapterText']; ?></a></li>
      <?php endforeach; ?>
    <?php else: ?>
      <li>No chapters available</li>
    <?php endif; ?>
  </ul>

  <p>
    <a href="<?=$data['data']['prevChapterLink'] ?? '#'; ?>">Previous Chapter</a> | 
    <a href="<?=$data['data']['allChaptersLink'] ?? '#'; ?>">All Chapters</a> | 
    <a href="<?=$data['data']['nextChapterLink'] ?? '#'; ?>">Next Chapter</a>
  </p>

  <a href="<?=$data['data']['downloadLink'] ?? '#'; ?>">Download Chapter</a>
</body>
</html>
